@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
-//  Copyright 2004-2011 SRI International
+//  Copyright 2004-2012 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3647 $
+//  $Revision: 4344 $
 //
-//  $LastChangedDate: 2011-12-22 10:49:31 -0800 (Thu, 22 Dec 2011) $
+//  $LastChangedDate: 2012-05-11 14:51:08 -0700 (Fri, 11 May 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -41,7 +41,8 @@
 #include <System/cmtkTimers.h>
 #include <System/cmtkStrUtility.h>
 
-#include <IO/cmtkClassStream.h>
+#include <IO/cmtkClassStreamInput.h>
+#include <IO/cmtkClassStreamOutput.h>
 #include <IO/cmtkTypedStreamStudylist.h>
 #include <IO/cmtkVolumeIO.h>
 
@@ -194,7 +195,7 @@ doMain( int argc, const char* argv[] )
     cmtk::SplineWarpXform::SmartPtr splineWarp = cmtk::SplineWarpXform::SmartPtr::DynamicCastFrom( studylist.GetWarpXform() );
     if ( splineWarp ) 
       {
-      std::string actualPath = cmtk::StrReplace( studylist.GetFloatingStudyPath(), ReplaceMap );
+      std::string actualPath = cmtk::StrReplaceByRules( studylist.GetFloatingStudyPath(), ReplaceMap );
       
       cmtk::UniformVolume::SmartPtr nextVolume;
 
@@ -233,7 +234,7 @@ doMain( int argc, const char* argv[] )
       }
     }
   
-  std::string actualPath = cmtk::StrReplace( studylist.GetReferenceStudyPath(), ReplaceMap );
+  std::string actualPath = cmtk::StrReplaceByRules( studylist.GetReferenceStudyPath(), ReplaceMap );
   cmtk::UniformVolume::SmartPtr refVolume( cmtk::VolumeIO::ReadOriented( actualPath.c_str() ) );
   
   if ( ! refVolume ) 
@@ -295,7 +296,7 @@ doMain( int argc, const char* argv[] )
   cmtk::WarpXform::SmartPtr warpXform;
   if ( InWarpName ) 
     {
-    cmtk::ClassStream stream( InWarpName, cmtk::ClassStream::MODE_READ );
+    cmtk::ClassStreamInput stream( InWarpName );
     stream >> warpXform;
     } 
   else
@@ -312,7 +313,7 @@ doMain( int argc, const char* argv[] )
       warpXform->ReplaceInitialAffine( (*(warpList.begin()))->GetInitialAffineXform() );
       }
       
-    cmtk::ClassStream stream( OutWarpName, cmtk::ClassStream::MODE_WRITE );
+    cmtk::ClassStreamOutput stream( OutWarpName, cmtk::ClassStreamOutput::MODE_WRITE );
     stream << warpXform;
     }
 
