@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
-//  Copyright 2004-2011 SRI International
+//  Copyright 2004-2012 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3647 $
+//  $Revision: 4427 $
 //
-//  $LastChangedDate: 2011-12-22 10:49:31 -0800 (Thu, 22 Dec 2011) $
+//  $LastChangedDate: 2012-06-12 11:23:22 -0700 (Tue, 12 Jun 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -38,7 +38,7 @@
 
 #include <Base/cmtkAffineXform.h>
 #include <IO/cmtkXformIO.h>
-#include <IO/cmtkClassStream.h>
+#include <IO/cmtkClassStreamOutput.h>
 #include <IO/cmtkClassStreamAffineXform.h>
 
 const char* OutputName = "concat.xform";
@@ -94,7 +94,7 @@ doMain( const int argc, const char* argv[] )
       concat.Concat( *affine );
       if ( firstXform )
 	{
-	concat.ChangeCenter( cmtk::FixedVector<3,cmtk::Types::Coordinate>( affine->RetCenter() ) );
+	concat.ChangeCenter( cmtk::FixedVector<3,cmtk::Types::Coordinate>::FromPointer( affine->RetCenter() ) );
 	firstXform = false;
 	}
       
@@ -107,12 +107,12 @@ doMain( const int argc, const char* argv[] )
     throw cmtk::ExitException( 1 );
     }
 
-  cmtk::ClassStream outStream;
+  cmtk::ClassStreamOutput outStream;
 
   if ( AppendToOutput )
-    outStream.Open( OutputName, cmtk::ClassStream::MODE_APPEND );
+    outStream.Open( OutputName, cmtk::ClassStreamOutput::MODE_APPEND );
   else
-    outStream.Open( OutputName, cmtk::ClassStream::MODE_WRITE );
+    outStream.Open( OutputName, cmtk::ClassStreamOutput::MODE_WRITE );
 
   if ( outStream.IsValid() )
     {
