@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4237 $
+//  $Revision: 4427 $
 //
-//  $LastChangedDate: 2012-04-20 14:55:20 -0700 (Fri, 20 Apr 2012) $
+//  $LastChangedDate: 2012-06-12 11:23:22 -0700 (Tue, 12 Jun 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -35,6 +35,7 @@
 #include <System/cmtkConsole.h>
 #include <System/cmtkDebugOutput.h>
 #include <System/cmtkCommandLine.h>
+#include <System/cmtkStrUtility.h>
 #include <System/cmtkExitException.h>
 
 #include <Base/cmtkMetaInformationObject.h>
@@ -91,6 +92,46 @@
 #define DCM_PatientsName DCM_PatientName
 #endif
 
+void
+AddPatternToMap( std::map<DcmTagKey,std::string>& map, const char* pattern )
+{
+  const char* equals = strchr( pattern, '=' );
+  if ( equals )
+    {
+    const std::string tagName( pattern, static_cast<size_t>( equals-pattern ) );
+
+    const DcmDictEntry* dictEntry = dcmDataDict.rdlock().findEntry( tagName.c_str() );
+    dcmDataDict.unlock();
+
+    if ( dictEntry )
+      {
+      map.insert( std::pair<DcmTagKey,std::string>( dictEntry->getKey(), equals+1 ) );      
+      }
+    else
+      {
+      cmtk::StdErr << "WARNING: DCMTK data dictionary does not have a tag entry named '" << tagName << "' - ignoring this\n";
+      }
+    }
+}
+
+// Map of file includion patterns
+std::map<DcmTagKey,std::string> IncludePatterns;
+
+void
+CallbackAddInclude( const char* pattern )
+{
+  AddPatternToMap( IncludePatterns, pattern );
+}
+
+// Map of file exclusion patterns
+std::map<DcmTagKey,std::string> ExcludePatterns;
+
+void
+CallbackAddExclude( const char* pattern )
+{
+  AddPatternToMap( ExcludePatterns, pattern );
+}
+
 const char* OutPathPattern = "image%n.nii";
 std::vector<std::string> SearchRootDirVector;
 
@@ -294,7 +335,7 @@ ImageFile::ImageFile( const char* filename )
     RawDataType( "unknown" ),
     IsDWI( false ),
     BValue( 0 ),
-    BVector( cmtk::FixedVector<3,double>::Init( 0.0 ) )
+    BVector( 0.0 )
 {
   if ( cmtk::FileFormat::Identify( filename, false /*decompress*/ ) != cmtk::FILEFORMAT_DICOM ) // need to disable "decompress" in Identify() because DCMTK cannot currently read using on-the-fly decompression.
     throw(0);
@@ -346,6 +387,40 @@ ImageFile::ImageFile( const char* filename )
     }
 
   const char* tmpStr = NULL;
+
+  // check for positive include list
+  if ( !IncludePatterns.empty() )
+    {
+    for ( std::map<DcmTagKey,std::string>::const_iterator it = IncludePatterns.begin(); it != IncludePatterns.end(); ++it )
+      {
+      // if tag not found, do not include
+      if ( document->getValue( it->first, tmpStr ) )
+	{
+	// if tag value matches, then include
+	if ( strstr( tmpStr, it->second.c_str() ) )
+	  continue;
+	}
+
+      // no match - exclude
+      throw( 3 );
+      }
+    }
+
+  // check for exclude list
+  if ( !ExcludePatterns.empty() )
+    {
+    for ( std::map<DcmTagKey,std::string>::const_iterator it = ExcludePatterns.begin(); it != ExcludePatterns.end(); ++it )
+      {
+      // only check tags that exist
+      if ( document->getValue( it->first, tmpStr ) )
+	{
+	// if tag value matches, exclude
+	if ( strstr( tmpStr, it->second.c_str() ) )
+	  throw( 4 );
+	}
+      }
+    }
+
   if ( document->getValue( DCM_Modality, tmpStr ) )
     this->Modality = tmpStr;
 
@@ -815,35 +890,10 @@ public:
   void WriteVolumes();
 };
 
-inline std::string&
-replacein(std::string& s, const std::string& sub, const std::string& other)
-{
-  assert(!sub.empty());
-  for ( size_t b = s.find(sub, 0); b != s.npos; b = s.find(sub, b) )
-    {
-    s.replace(b, sub.size(), other);
-    b += other.size();
-    }
-  return s;
-}
-
-/// Make a string legal in a path by replacing spaces and colons with "_".
-std::string
-MakeLegalInPath( const std::string& s )
-{
-  std::string result = s;
-
-  result = replacein( result, " ", "_" );      
-  result = replacein( result, ":", "_" );  
-
-  return result;
-}
-
 std::string
 PutNumberAndSanitize( const std::string& path, const std::string& numberString )
 {
-  std::string result = path;
-  return replacein( replacein( result, "%n", numberString ), "%N", "-" + numberString );
+  return cmtk::StrReplace( cmtk::StrReplace( path, "%n", numberString ), "%N", "-" + numberString );
 }
 
 void
@@ -858,10 +908,10 @@ VolumeList::WriteVolumes()
       {
       // replace place holders
       std::string path( OutPathPattern );
-      replacein( path, "%D", MakeLegalInPath( (*it)[0][0]->SeriesDescription ) );
-      replacein( path, "%R", MakeLegalInPath( (*it)[0][0]->RepetitionTime ) );
-      replacein( path, "%E", MakeLegalInPath( (*it)[0][0]->EchoTime ) );
-      replacein( path, "%T", (*it)[0][0]->RawDataType );
+      path = cmtk::StrReplace( path, "%D", cmtk::StrMakeLegalInPath( (*it)[0][0]->SeriesDescription ) );
+      path = cmtk::StrReplace( path, "%R", cmtk::StrMakeLegalInPath( (*it)[0][0]->RepetitionTime ) );
+      path = cmtk::StrReplace( path, "%E", cmtk::StrMakeLegalInPath( (*it)[0][0]->EchoTime ) );
+      path = cmtk::StrReplace( path, "%T", (*it)[0][0]->RawDataType );
       
       if ( path.length() > PATH_MAX )
 	cmtk::StdErr << "ERROR: output path exceeds maximum path length";
@@ -1108,8 +1158,8 @@ doMain ( const int argc, const char *argv[] )
 		  "%n (image number with automatic number of digits); "
 		  "%N (like %n, but with a hyphen '-' before number if there is more than one image); "
 		  "%D (DICOM SeriesDescription); "
-		  "%R (DICOM RepetitionTime - MRI only)"
-		  "%E (DICOM EchoTime - MRI only)"
+		  "%R (DICOM RepetitionTime - MRI only); "
+		  "%E (DICOM EchoTime - MRI only); "
 		  "%T (RawDataType - vendor-specific, currently GE MRI only)" );
 
     cl.AddSwitch( Key( 'x', "xml" ), &WriteXML, true, "Write XML sidecar file for each created image." );
@@ -1122,6 +1172,13 @@ doMain ( const int argc, const char *argv[] )
     embedGroup->AddSwitch( Key( "None" ), EMBED_NONE, "Embed no information - leave 'description' field empty." );
     cl.EndGroup();
 
+    cl.BeginGroup( "Filtering", "Filtering Options")->SetProperties( cmtk::CommandLine::PROPS_ADVANCED );
+    cl.AddCallback( Key( "filter" ), &CallbackAddInclude, "Filter DICOM files and include only those matching the given pattern of the form 'TagName=text', such that the value of the DICOM tag with the given name contains the given "
+		    "text. If multiple filter patterns are provided via repeated use of this option, only files that match ALL patterns are included." );
+    cl.AddCallback( Key( "exclude" ), &CallbackAddExclude, "Exclude all DICOM files matching the given pattern of the form 'TagName=text', such that the value of the DICOM tag with the given name contains the given text. "
+      "If multiple exclusion patterns are provided, all files are excluded that match ANY of the patterns." );
+    cl.EndGroup();
+
     cl.BeginGroup( "Sorting", "Sorting Options")->SetProperties( cmtk::CommandLine::PROPS_ADVANCED );
     cl.AddSwitch( Key( "no-sort" ), &SortFiles, SORT_NONE, "Do NOT sort files by file name (sorting determines image stack order when resolving spatial collisions)" );
     cl.AddSwitch( Key( "sort-by-name" ), &SortFiles, SORT_FILENAME, "Sort files lexicographically by file name. Use this when instance numbers are non-unique." );
