@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3977 $
+//  $Revision: 4427 $
 //
-//  $LastChangedDate: 2012-03-06 15:30:28 -0800 (Tue, 06 Mar 2012) $
+//  $LastChangedDate: 2012-06-12 11:23:22 -0700 (Tue, 12 Jun 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -47,6 +47,8 @@
 #include <stdio.h>
 #include <math.h>
 
+#include <limits>
+
 cmtk::Types::Coordinate Accuracy = 0.01;
 bool NoCheck = false;
 bool Forward = false;
@@ -77,7 +79,8 @@ doMain( const int argc, const char *argv[] )
     {
     cmtk::CommandLine cl;
     cl.SetProgramInfo( cmtk::CommandLine::PRG_TITLE, "Apply coordinate transformations to lists of point coordinates" );
-    cl.SetProgramInfo( cmtk::CommandLine::PRG_DESCR, "This tool reads a list of 3D coordinates and applies a coordimnate transformation to them. The transformation can optionally be inverted. The transformed coordinates are then written to standard output." );
+    cl.SetProgramInfo( cmtk::CommandLine::PRG_DESCR, "THIS TOOL IS DEPRECATED. PLEASE USE streamxform INSTEAD.\n\n"
+		       "This tool reads a list of 3D coordinates and applies a coordimnate transformation to them. The transformation can optionally be inverted. The transformed coordinates are then written to standard output." );
     cl.SetProgramInfo( cmtk::CommandLine::PRG_SYNTX, "gregxform [options] transformation" );      
 
     typedef cmtk::CommandLine::Key Key;
@@ -187,7 +190,7 @@ doMain( const int argc, const char *argv[] )
     
     if ( numRead == 3 ) 
       {
-      cmtk::FixedVector<3,cmtk::Types::Coordinate> v( xyz );
+      cmtk::FixedVector<3,cmtk::Types::Coordinate> v = cmtk::FixedVector<3,cmtk::Types::Coordinate>::FromPointer( xyz );
       cmtk::FixedVector<3,cmtk::Types::Coordinate> u( v );
       cmtk::FixedVector<3,cmtk::Types::Coordinate> uu;
 
@@ -283,7 +286,7 @@ doMain( const int argc, const char *argv[] )
 	{
 	if(Binary)
 	  {
-	  const float nan3[3] = { cmtk::MathUtil::GetFloatNaN(), cmtk::MathUtil::GetFloatNaN(), cmtk::MathUtil::GetFloatNaN()};
+	  const float nan3[3] = { std::numeric_limits<float>::signaling_NaN(), std::numeric_limits<float>::signaling_NaN(), std::numeric_limits<float>::signaling_NaN()};
 	  fwrite( nan3, sizeof(float), 3, outfile );
 	  }
 	else
