@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3980 $
+//  $Revision: 4350 $
 //
-//  $LastChangedDate: 2012-03-06 15:54:24 -0800 (Tue, 06 Mar 2012) $
+//  $LastChangedDate: 2012-05-15 15:20:24 -0700 (Tue, 15 May 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -348,12 +348,10 @@ CallbackSqrt()
 }
         
 void
-CallbackThreshBelow( const char* argv )
+CallbackThreshBelow( const double threshold )
 {
   CheckStackOneImage( "ThreshBelow" );
 
-  const cmtk::Types::DataItem threshold = static_cast<cmtk::Types::DataItem>( atof( argv ) );
-  
   ImageStackType::iterator it = ImageStack.begin();
   while ( it != ImageStack.end() )
     {
@@ -371,12 +369,10 @@ CallbackThreshBelow( const char* argv )
 }
     
 void
-CallbackThreshAbove( const char* argv )
+CallbackThreshAbove( const double threshold )
 {
   CheckStackOneImage( "ThreshAbove" );
 
-  const cmtk::Types::DataItem threshold = static_cast<cmtk::Types::DataItem>( atof( argv ) );
-  
   ImageStackType::iterator it = ImageStack.begin();
   while ( it != ImageStack.end() )
     {
