@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
-//  Copyright 2004-2011 SRI International
+//  Copyright 2004-2012 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3647 $
+//  $Revision: 4431 $
 //
-//  $LastChangedDate: 2011-12-22 10:49:31 -0800 (Thu, 22 Dec 2011) $
+//  $LastChangedDate: 2012-06-13 11:17:08 -0700 (Wed, 13 Jun 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -50,7 +50,8 @@
 
 #include <IO/cmtkVolumeIO.h>
 #include <IO/cmtkXformIO.h>
-#include <IO/cmtkClassStream.h>
+#include <IO/cmtkClassStreamInput.h>
+#include <IO/cmtkClassStreamOutput.h>
 
 #include <Registration/cmtkSymmetryPlaneFunctional.h>
 #include <Registration/cmtkBestNeighbourOptimizer.h>
@@ -201,7 +202,7 @@ ParseCommandLine ( const int argc, const char* argv[] )
     
     if ( SymmetryParametersFile ) 
       {
-      cmtk::ClassStream inStream( SymmetryParametersFile, cmtk::ClassStream::MODE_READ );
+      cmtk::ClassStreamInput inStream( SymmetryParametersFile );
       if ( inStream.IsValid() ) 
 	{
 	cmtk::ParametricPlane *plane = NULL;
@@ -437,7 +438,7 @@ doMain ( const int argc, const char* argv[] )
       if ( level < Levels-1 ) 
 	{
 	cmtk::Types::Coordinate voxelSize = Sampling * pow( 2.0, (Levels-level-2) );
-	volume = cmtk::UniformVolume::SmartPtr( new cmtk::UniformVolume( *originalVolume, voxelSize ) );
+	volume = cmtk::UniformVolume::SmartPtr( originalVolume->GetResampled( voxelSize ) );
 	cmtk::DebugOutput( 1 ).GetStream().printf( "Entering level %d out of %d (%.2f mm voxel size)\n", level+1, Levels, voxelSize );
 	} 
       else
@@ -479,7 +480,7 @@ doMain ( const int argc, const char* argv[] )
   
   if ( SymmetryOutFileName )
     {
-    cmtk::ClassStream stream( SymmetryOutFileName, cmtk::ClassStream::MODE_WRITE );
+    cmtk::ClassStreamOutput stream( SymmetryOutFileName, cmtk::ClassStreamOutput::MODE_WRITE );
     stream << parametricPlane;
     stream.Close();
     }
