@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3750 $
+//  $Revision: 4427 $
 //
-//  $LastChangedDate: 2012-01-26 13:59:12 -0800 (Thu, 26 Jan 2012) $
+//  $LastChangedDate: 2012-06-12 11:23:22 -0700 (Tue, 12 Jun 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -161,7 +161,7 @@ ActiveDeformationModel<W>::MakeSamplePoints( const W* deformation )
   Vector3D u;
   for ( unsigned int pointIdx = 0; pointIdx < numberOfParameters / 3; ++pointIdx, ptr += 3 ) 
     {
-    FixedVector<3,Types::Coordinate> v( ptr );
+    FixedVector<3,Types::Coordinate> v = FixedVector<3,Types::Coordinate>::FromPointer( ptr );
     
     // undo affine transformation component
     xform->ApplyInPlace( v );
