@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4236 $
+//  $Revision: 4427 $
 //
-//  $LastChangedDate: 2012-04-20 14:55:02 -0700 (Fri, 20 Apr 2012) $
+//  $LastChangedDate: 2012-06-12 11:23:22 -0700 (Tue, 12 Jun 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -97,29 +97,6 @@ AffineXform::AffineXform
   this->DecomposeMatrix();
 }
 
-AffineXform::AffineXform
-( const Types::Coordinate matrix[4][4], const Types::Coordinate xlate[3],
-  const Types::Coordinate center[3] ) :
-  Matrix( &matrix[0][0] ), 
-  m_LogScaleFactors( false ),
-  InverseXform( NULL )
-{
-  this->AllocateParameterVector( TotalNumberOfParameters );
-  this->NumberDOFs = this->DefaultNumberOfDOFs();
-  Types::Coordinate cM[3] = 
-    {
-      center[0]*Matrix[0][0] + center[1]*Matrix[1][0] + center[2]*Matrix[2][0],
-      center[0]*Matrix[0][1] + center[1]*Matrix[1][1] + center[2]*Matrix[2][1],
-      center[0]*Matrix[0][2] + center[1]*Matrix[1][2] + center[2]*Matrix[2][2]
-    };
-  
-  Matrix[3][0] = xlate[0] + center[0] - cM[0];
-  Matrix[3][1] = xlate[1] + center[1] - cM[1];
-  Matrix[3][2] = xlate[2] + center[2] - cM[2];
-
-  this->Matrix.Decompose( this->m_Parameters, center, this->m_LogScaleFactors );
-}
-
 AffineXform& 
 AffineXform::operator=( const AffineXform& other )
 {
@@ -200,7 +177,7 @@ AffineXform::MakeInverse () const
   inverseXform->Matrix = this->Matrix.GetInverse();
   inverseXform->DecomposeMatrix();
 
-  const Self::SpaceVectorType newCenter = Self::SpaceVectorType( this->RetCenter() ) * this->Matrix;
+  const Self::SpaceVectorType newCenter = Self::SpaceVectorType::FromPointer( this->RetCenter() ) * this->Matrix;
   inverseXform->ChangeCenter( newCenter );
   
   if ( this->NumberDOFs == 7 ) 
@@ -221,7 +198,7 @@ AffineXform::ChangeCenter ( const Self::SpaceVectorType& newCenter )
 {
   Types::Coordinate *const xlate = this->RetXlate();
   Types::Coordinate *const center = this->RetCenter();
-  Self::SpaceVectorType deltaCenter = newCenter - Self::SpaceVectorType( center );
+  Self::SpaceVectorType deltaCenter = newCenter - Self::SpaceVectorType::FromPointer( center );
   
   for ( size_t i = 0; i<3; ++i )
     xlate[i] -= deltaCenter[i];
@@ -243,44 +220,6 @@ AffineXform::SetMatrix( const MatrixType& matrix )
   this->UpdateInverse();
 }
 
-void
-AffineXform::SetMatrix( const float matrix[4][4] ) 
-{
-  for ( unsigned int j = 0; j < 4; ++j )
-    for ( unsigned int i = 0; i < 4; ++i )
-      Matrix[j][i] = matrix[j][i];
-  this->DecomposeMatrix();
-  this->UpdateInverse();
-}
-
-void
-AffineXform::SetMatrix( const double matrix[4][4] ) 
-{
-  for ( unsigned int j = 0; j < 4; ++j )
-    for ( unsigned int i = 0; i < 4; ++i )
-      Matrix[j][i] = matrix[j][i];
-  this->DecomposeMatrix();
-  this->UpdateInverse();
-}
-
-template<> 
-void
-AffineXform::GetMatrix( float (&matrix)[4][4] ) const
-{
-  for ( unsigned int j = 0; j < 4; ++j )
-    for ( unsigned int i = 0; i < 4; ++i )
-      matrix[j][i] = static_cast<float>( Matrix[j][i] );
-}
-
-template<> 
-void 
-AffineXform::GetMatrix( double (&matrix)[4][4] ) const
-{
-  for ( unsigned int j = 0; j < 4; ++j )
-    for ( unsigned int i = 0; i < 4; ++i )
-      matrix[j][i] = static_cast<double>( Matrix[j][i] );
-}
-
 void
 AffineXform::SetParamVector ( CoordinateVector& v )
 {
@@ -379,9 +318,9 @@ AffineXform::RotateWXYZ
 
   Self::SpaceVectorType center3D;
   if ( center ) 
-    center3D = Self::SpaceVectorType( center );
+    center3D = Self::SpaceVectorType::FromPointer( center );
   else
-    center3D = Self::SpaceVectorType( this->RetCenter() );
+    center3D = Self::SpaceVectorType::FromPointer( this->RetCenter() );
 
   if ( accumulate ) 
     {
