@@ -22,11 +22,11 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4230 $
+//  $Revision: 4398 $
 //
-//  $LastChangedDate: 2012-04-19 14:27:53 -0700 (Thu, 19 Apr 2012) $
+//  $LastChangedDate: 2012-05-31 11:48:23 -0700 (Thu, 31 May 2012) $
 //
-//  $LastChangedBy: torstenrohlfing $
+//  $LastChangedBy: torsten_at_home $
 //
 */
 
@@ -58,7 +58,7 @@ cmtk
  * the matrix itself or a parameter vector. Both representations are 
  * permanently accessible and held mutually up-to-date whenever one of them
  * changes.
- *\author $Author: torstenrohlfing $
+ *\author $Author: torsten_at_home $
  */
 class AffineXform : 
   /// Inherit virtual interface from generic transformation.
@@ -162,16 +162,6 @@ public:
    */
   AffineXform ( const MatrixType& matrix, const Types::Coordinate* center = NULL );
 
-  /** Create transformation from transformation matrix.
-   * Translation vector and rotation center are given in addition to the
-   * 4x4 transformation matrix..
-   *\param matrix The homogeneous 4x4 affine transformation matrix. If a
-   * translation is defined by this matrix, it is ignored.
-   *\param xlate Translation of the constructed transformation.
-   *\param center Rotation center of the constructed transformation.
-   */
-  AffineXform ( const Types::Coordinate matrix[4][4], const Types::Coordinate xlate[3], const Types::Coordinate center[3] );
-  
   /// Copy transform by reference.
   AffineXform ( const AffineXform& other );
   
@@ -434,12 +424,7 @@ public:
   Types::Coordinate* RetMatrix () { return &Matrix[0][0]; }
 
   /// Set transformation matrix.
-  void SetMatrix( const float matrix[4][4] );
-  void SetMatrix( const double matrix[4][4] );
   void SetMatrix( const MatrixType& matrix );
-
-  /// Get transformation matrix.
-  template<class T> void GetMatrix( T (&matrix)[4][4] ) const;
   //@}
 
   /** Create equivalent transformation with different rotational center.
