@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
-//  Copyright 2004-2011 SRI International
+//  Copyright 2004-2012 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3642 $
+//  $Revision: 4427 $
 //
-//  $LastChangedDate: 2011-12-21 14:50:10 -0800 (Wed, 21 Dec 2011) $
+//  $LastChangedDate: 2012-06-12 11:23:22 -0700 (Tue, 12 Jun 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -41,8 +41,17 @@ namespace
 cmtk
 {
 
-/** \addtogroup Base */
-//@{
+DataGrid::DataGrid( const Self& other ) 
+  : MetaInformationObject( other ), 
+    m_Dims( other.m_Dims ), 
+    m_GridIncrements( other.m_GridIncrements ),
+    m_CropRegion( other.m_CropRegion )
+{
+  if (other.m_Data )
+    this->m_Data = other.m_Data->Clone();
+
+  this->ComputeGridIncrements();
+}
 
 DataGrid*
 DataGrid::CloneVirtual( const bool copyData )
@@ -78,8 +87,7 @@ DataGrid::CloneVirtual() const
 const DataGrid::RegionType
 DataGrid::GetWholeImageRegion() const
 {
-  const int zeroes[3] = {0,0,0};
-  return Self::RegionType( Self::IndexType( zeroes ), Self::IndexType( this->m_Dims ) );
+  return Self::RegionType( Self::IndexType( 0 ), Self::IndexType( this->m_Dims ) );
 }
 
 TypedArray::SmartPtr
@@ -97,8 +105,7 @@ DataGrid::GetDownsampledAndAveraged( const int (&downsample)[3] ) const
 {
   const int newDims[3] = { (this->m_Dims[0]-1) / downsample[0] + 1, (this->m_Dims[1]-1) / downsample[1] + 1, (this->m_Dims[2]-1) / downsample[2] + 1 };
 
-  DataGrid* newDataGrid = new DataGrid;
-  newDataGrid->SetDims( Self::IndexType( newDims ) );
+  DataGrid* newDataGrid = new DataGrid( Self::IndexType::FromPointer( newDims ) );
   
   const TypedArray* thisData = this->GetData();
   if ( thisData )
@@ -160,8 +167,7 @@ DataGrid::GetDownsampled( const int (&downsample)[3] ) const
 {
   const int newDims[3] = { (this->m_Dims[0]-1) / downsample[0] + 1, (this->m_Dims[1]-1) / downsample[1] + 1, (this->m_Dims[2]-1) / downsample[2] + 1 };
 
-  DataGrid* newDataGrid = new DataGrid;
-  newDataGrid->SetDims( Self::IndexType( newDims ) );
+  DataGrid* newDataGrid = new DataGrid( Self::IndexType::FromPointer( newDims ) );
   
   const TypedArray* thisData = this->GetData();
   if ( thisData )
@@ -253,11 +259,8 @@ DataGrid::GetReoriented( const char* newOrientation ) const
 }
 
 void
-DataGrid::SetDims( const Self::IndexType& dims )
+DataGrid::ComputeGridIncrements()
 {
-  this->m_Dims = dims;
-  this->m_CropRegion = this->GetWholeImageRegion();
-
   this->m_GridIncrements[0] = 1;
   for ( int i = 1; i < 3; ++i )
     this->m_GridIncrements[i] = this->m_GridIncrements[i-1] * this->m_Dims[i-1];
@@ -595,7 +598,7 @@ FixedVector<3,Types::Coordinate>
 DataGrid
 ::GetCenterOfMassGrid() const
 {
-  FixedVector<3,Types::Coordinate> com( FixedVector<3,Types::Coordinate>::Init( 0 ) );
+  FixedVector<3,Types::Coordinate> com( 0.0 );
 
   double sumOfSamples = 0;
   size_t ofs = 0;
@@ -607,7 +610,7 @@ DataGrid
 	if ( this->GetDataAt( value, x, y, z ) )
 	  {
 	  const Types::Coordinate pixelCOM[3] = { value * x, value * y, value * z };
-	  com += Self::SpaceVectorType( pixelCOM );
+	  com += Self::SpaceVectorType::FromPointer( pixelCOM );
 	  sumOfSamples += value;
 	  }
 	}
@@ -622,7 +625,7 @@ DataGrid
 ::GetCenterOfMassGrid(  FixedVector<3,Types::Coordinate>& firstOrderMoment ) const
 {
   FixedVector<3,Types::Coordinate> com = this->Self::GetCenterOfMassGrid(); // do not use overloaded function
-  firstOrderMoment = FixedVector<3,Types::Coordinate>( FixedVector<3,Types::Coordinate>::Init( 0 ) );
+  firstOrderMoment = FixedVector<3,Types::Coordinate>( 0.0 );
 
   double sumOfSamples = 0;
   size_t ofs = 0;
@@ -634,7 +637,7 @@ DataGrid
 	if ( this->GetDataAt( value, x, y, z ) )
 	  {
 	  const Types::Coordinate pixelMoment[3] = { value * fabs(x - com[0]), value * fabs(y - com[1]), value * fabs(z - com[2]) };
-	  firstOrderMoment += Self::SpaceVectorType( pixelMoment );
+	  firstOrderMoment += Self::SpaceVectorType::FromPointer( pixelMoment );
 	  sumOfSamples += value;
 	  }
 	}
