@@ -1,6 +1,6 @@
 /*
 //
-//  Copyright 2010, 2011 SRI International
+//  Copyright 2010-2012 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -20,9 +20,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3646 $
+//  $Revision: 4427 $
 //
-//  $LastChangedDate: 2011-12-22 10:10:55 -0800 (Thu, 22 Dec 2011) $
+//  $LastChangedDate: 2012-06-12 11:23:22 -0700 (Tue, 12 Jun 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -49,5 +49,5 @@ cmtk::ImageOperationCropRegion
     throw "Expected six comma-separated integer values.";
     }
   
-  ImageOperation::m_ImageOperationList.push_back( SmartPtr( new ImageOperationCropRegion( DataGrid::RegionType( DataGrid::IndexType(from), DataGrid::IndexType(to) ) ) ) );
+  ImageOperation::m_ImageOperationList.push_back( SmartPtr( new ImageOperationCropRegion( DataGrid::RegionType( DataGrid::IndexType::FromPointer(from), DataGrid::IndexType::FromPointer(to) ) ) ) );
 }
