@@ -20,9 +20,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3945 $
+//  $Revision: 4236 $
 //
-//  $LastChangedDate: 2012-02-29 11:33:37 -0800 (Wed, 29 Feb 2012) $
+//  $LastChangedDate: 2012-04-20 14:55:02 -0700 (Fri, 20 Apr 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -52,9 +52,7 @@ cmtk::ImageOperationMedialSkeleton
 	{
 // Ridgeness operator implemented following http://en.wikipedia.org/wiki/Ridge_detection#Definition_of_ridges_and_valleys_in_N_dimensions
 	
-	Matrix3x3<Types::DataItem> hessian;
-	iMap->GetHessianAt( hessian, i, j, k );
-	
+	const Matrix3x3<Types::DataItem> hessian = iMap->GetHessianAt( i, j, k );	
 	EigenSystemSymmetricMatrix3x3<Types::DataItem> eigenSystem( hessian, false /*sortAbsolute*/ );
 	
 	Types::DataItem result = iMap->GetDataAt( i, j, k );
