@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4268 $
+//  $Revision: 4379 $
 //
-//  $LastChangedDate: 2012-04-27 14:46:49 -0700 (Fri, 27 Apr 2012) $
+//  $LastChangedDate: 2012-05-30 13:22:10 -0700 (Wed, 30 May 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -105,38 +105,6 @@ public:
     return finite( value ) != 0;
   }
 
-  /// Get double-precision not-a-number (NaN) value.
-  static double GetDoubleNaN()
-  {
-    return Self::GetInternalNaN().m_Union.d;
-  }
-  
-  /// Get single-precision not-a-number (NaN) value.
-  static float GetFloatNaN()
-  {
-#if WORDS_BIGENDIAN
-    return Self::GetInternalNaN().m_Union.f[0];
-#else
-    return Self::GetInternalNaN().m_Union.f[1];
-#endif
-  }
-  
-  /// Get double-precision infinite (Inf) value.
-  static double GetDoubleInf()
-  {
-    return Self::GetInternalInf().m_Union.d;
-  }
-
-  /// Get single-precision infinite (Inf) value.
-  static float GetFloatInf()
-  {
-#if WORDS_BIGENDIAN
-    return Self::GetInternalInf().m_Union.f[0];
-#else
-    return Self::GetInternalInf().m_Union.f[1];
-#endif
-  }
-
   /// Unit-safe sin() function.
   static double Sin( const Units::Radians& radians )
   {
@@ -167,7 +135,7 @@ public:
     return Units::Radians( acos( value ) );
   }
   
-  /// Unit-safe aten() function.
+  /// Unit-safe atan() function.
   static const Units::Radians ArcTan( const double value )
   {
     return Units::Radians( atan( value ) );
@@ -329,10 +297,10 @@ public:
   /// Function that compares two doubles; to be used in qsort().
   static inline int CompareDouble( const void *a, const void *b ) 
   {
-    const double* A = static_cast<const double*>( a );
-    const double* B = static_cast<const double*>( b );
-    if ( *A > *B ) return +1;
-    if ( *A < *B ) return -11;
+    const double A = *(static_cast<const double*>( a ));
+    const double B = *(static_cast<const double*>( b ));
+    if ( A > B ) return +1;
+    if ( A < B ) return -1;
     return 0;
   }
   
@@ -350,17 +318,19 @@ public:
     static bool secondNumberReady = false;
     static double secondNumber = 0;
     
-    if ( secondNumberReady ) {
-    secondNumberReady = false;
-    return secondNumber;
-    }
+    if ( secondNumberReady ) 
+      {
+      secondNumberReady = false;
+      return secondNumber;
+      }
     
     double x1, x2, w;
-    do {
-    x1 = 2.0 * (random()&0xffffff)/0x1000000 - 1.0;
-    x2 = 2.0 * (random()&0xffffff)/0x1000000 - 1.0;
-    w = x1 * x1 + x2 * x2;
-    } while ( w >= 1.0 );
+    do 
+      {
+      x1 = 2.0 * (random()&0xffffff)/0x1000000 - 1.0;
+      x2 = 2.0 * (random()&0xffffff)/0x1000000 - 1.0;
+      w = x1 * x1 + x2 * x2;
+      } while ( w >= 1.0 );
     
     w = sqrt( (-2.0 * log( w ) ) / w );
     secondNumber = x1 * w * sigma;
@@ -390,56 +360,6 @@ public:
 
   /// Determinant of an n x n square matrix.
   template<class T> static T CholeskyDeterminant( const Matrix2D<T>& matrix, int n);
-
-private:
-  /// Helper class to initialize a constant 64bit field.
-  class BitInitializer
-  {
-  public:
-    /// Union that is used for initializing variables of different types with bitfield values.
-    typedef union
-    {
-      /// Write bit pattern for special values here.
-      uint32_t i[2];
-      /// Read out for single-precision special value.
-      float f[2];
-      /// Read out for double-precision special value.
-      double d;
-    } InitializeUnion;
-    
-    /// The actual initializer memory.
-    InitializeUnion m_Union;
-    
-  public:
-    /// Initialize 64bit field with two given 32bit integers.
-    BitInitializer( const uint32_t i0, const uint32_t i1 )
-    {
-      this->m_Union.i[0] = i0;
-      this->m_Union.i[1] = i1;
-    }
-  };
-  
-  /// Get reference to internal representation of NaN.
-  static const Self::BitInitializer& GetInternalNaN()
-  {
-#if WORDS_BIGENDIAN
-    static const Self::BitInitializer bits( 0x7fffffff, 0xffffffff );
-#else
-    static const Self::BitInitializer bits( 0xffffffff, 0x7fffffff );
-#endif
-    return bits;
-  }
-  
-  /// Get reference to internal representation of Inf.
-  static const Self::BitInitializer& GetInternalInf()
-  {
-#if WORDS_BIGENDIAN
-    static const Self::BitInitializer bits( 0x7f800000, 0x00000000 );
-#else
-    static const Self::BitInitializer bits( 0x00000000, 0x7f800000 );
-#endif
-    return bits;
-  }
 };
 
 //@}
