@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3871 $
+//  $Revision: 4427 $
 //
-//  $LastChangedDate: 2012-02-15 14:39:46 -0800 (Wed, 15 Feb 2012) $
+//  $LastChangedDate: 2012-06-12 11:23:22 -0700 (Tue, 12 Jun 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -159,8 +159,7 @@ SplineWarpXform::InitControlPoints( const AffineXform* affineXform )
     ofs = this->m_Parameters;
     for ( unsigned int idx = 0; idx < this->m_NumberOfControlPoints; ++idx, ofs+=3 ) 
       {
-      Self::SpaceVectorType p( ofs );
-      affineXform->ApplyInPlace( p );
+      const Self::SpaceVectorType p = affineXform->Apply( Self::SpaceVectorType::FromPointer( ofs ) );
       ofs[0] = p[0];
       ofs[1] = p[1];
       ofs[2] = p[2];
@@ -466,7 +465,7 @@ void
 SplineWarpXform::RegisterVolumePoints
 ( const DataGrid::IndexType& volDims, const Self::SpaceVectorType& delta, const Self::SpaceVectorType& origin )
 {
-  const size_t ijk[3] = { this->nextI, this->nextJ, this->nextK };
+  const int ijk[3] = { this->nextI, this->nextJ, this->nextK };
   for ( int axis = 0; axis < 3; ++axis )    
     this->RegisterVolumeAxis( volDims[axis], delta[axis], origin[axis], this->m_Dims[axis], ijk[axis], this->m_InverseSpacing[axis], 
 			      this->m_GridIndexes[axis], this->m_GridOffsets[axis], this->m_GridSpline[axis], this->m_GridDerivSpline[axis] );
@@ -982,11 +981,9 @@ SplineWarpXform::GetPureDeformation( const bool includeScale ) const
   Self::SpaceVectorType u;
   for ( size_t pointIdx = 0; pointIdx < numberOfParameters / 3; ++pointIdx, ptr += 3 ) 
     {
-    Self::SpaceVectorType v( ptr );
-    
     // undo affine transformation component
-    xform->ApplyInPlace( v );
-    
+    const Self::SpaceVectorType v = xform->Apply( Self::SpaceVectorType::FromPointer( ptr ) );
+
     // copy the result into ouput array
     for ( unsigned int dim = 0; dim < 3; ++dim ) 
       ptr[dim] = v[dim];
