@@ -22,11 +22,11 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4275 $
+//  $Revision: 4415 $
 //
-//  $LastChangedDate: 2012-04-29 12:39:40 -0700 (Sun, 29 Apr 2012) $
+//  $LastChangedDate: 2012-06-04 14:57:12 -0700 (Mon, 04 Jun 2012) $
 //
-//  $LastChangedBy: torsten_at_home $
+//  $LastChangedBy: torstenrohlfing $
 //
 */
 
@@ -277,7 +277,7 @@ public:
   }
   
   /// Precompute spline parameters for one point.
-  void PrecomputeLocationSpline( const Self::SpaceVectorType& v, FixedVector<3,int>& grid, FixedVector< 3, FixedVector<4,Types::Coordinate> >& spline  ) const
+  void PrecomputeLocationSpline( const Self::SpaceVectorType& v, FixedVector<3,int>& grid, FixedArray< 3, FixedVector<4,Types::Coordinate> >& spline  ) const
   {
     for ( int dim = 0; dim<3; ++dim ) 
       {
@@ -308,9 +308,9 @@ public:
 								    const bool fastMode /*!< Fast mode selector. When 0, "slow", accurate mode is forced. */ ) const;
   
   /// Register the grid points of the deformed uniform or non-uniform volume.
-  void RegisterVolume( const UniformVolume* volume )
+  void RegisterVolume( const UniformVolume& volume )
   {
-    this->RegisterVolumePoints( volume->m_Dims, volume->m_Delta, volume->m_Offset );
+    this->RegisterVolumePoints( volume.m_Dims, volume.m_Delta, volume.m_Offset );
   }
 
   /// Register axes points of the volume to be deformed.
@@ -388,7 +388,7 @@ protected:
    * These arrays hold the precomputed grid indexes of the deformed grid's
    * voxels with respect to the control point grid of this deformation. 
    */
-  FixedVector< 3,std::vector<int> > m_GridIndexes;
+  FixedArray< 3,std::vector<int> > m_GridIndexes;
 
   /**\name Precomputed coefficient array offsets.
    * These arrays hold the precomputed grid offsets of the deformed grid's
@@ -396,20 +396,20 @@ protected:
    * values are the grid indexes multiplied by the number of elements to skip in
    * the coefficient array that corresponds to the respective index.
    */
-  FixedVector< 3,std::vector<int> > m_GridOffsets;
+  FixedArray< 3,std::vector<int> > m_GridOffsets;
 
   /**\name Precomputed spline coefficients.
    * These arrays hold the precomputed spline coefficients for deforming the
    * voxel locations in the associated deformed grid.
    */
-  FixedVector< 3,std::vector<Types::Coordinate> > m_GridSpline;
+  FixedArray< 3,std::vector<Types::Coordinate> > m_GridSpline;
   
   /**\name Precomputed derivative spline coefficients.
    * These arrays hold the precomputed derivatives of the spline coefficients.
    * This allows for rapid evaluation of the Jacobian determinant.
    */
   /// x-axis.
-  FixedVector< 3,std::vector<Types::Coordinate> > m_GridDerivSpline;
+  FixedArray< 3,std::vector<Types::Coordinate> > m_GridDerivSpline;
 
   /// Relative offsets of all control points in a 4 x 4 x 4 neighborhood.
   int GridPointOffset[48];
@@ -449,6 +449,9 @@ protected:
   /// Fitting class is a friend.
   friend class FitSplineWarpToDeformationField;
 
+  /// Fitting class is a friend.
+  friend class FitSplineWarpToXformList;
+
   /// Fitting class is a friend.
   friend class FitSplineWarpToLandmarks;
 };
