@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3750 $
+//  $Revision: 4236 $
 //
-//  $LastChangedDate: 2012-01-26 13:59:12 -0800 (Thu, 26 Jan 2012) $
+//  $LastChangedDate: 2012-04-20 14:55:02 -0700 (Fri, 20 Apr 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -134,10 +134,7 @@ SplineWarpXform::ApplyInverseInPlaceWithInitial
   while ( ( error > accuracy) && (step > 0.001) ) 
     {
     // transform difference vector into original coordinate system using inverse Jacobian.
-    CoordinateMatrix3x3 J;
-    this->GetJacobian( u, J );
-    J.Invert3x3();
-    J.GetTranspose().Multiply( delta );
+    delta *= this->GetJacobian( u ).GetInverse().GetTranspose();
     
     // initialize line search
     (vu = u) -= (delta *= step);
