@@ -22,11 +22,11 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4103 $
+//  $Revision: 4395 $
 //
-//  $LastChangedDate: 2012-03-30 13:47:33 -0700 (Fri, 30 Mar 2012) $
+//  $LastChangedDate: 2012-05-31 11:02:03 -0700 (Thu, 31 May 2012) $
 //
-//  $LastChangedBy: torstenrohlfing $
+//  $LastChangedBy: torsten_at_home $
 //
 */
 
@@ -40,6 +40,9 @@
 
 #include <System/cmtkConsole.h>
 
+#include <cmath> // for float abs()
+#include <cstdlib> // for int abs()
+
 namespace
 cmtk
 {
@@ -101,7 +104,7 @@ public:
   TemplateArray ( void *const data, const size_t datasize, const bool paddingflag, const void* paddingData, const Memory::DeallocatorFunctionPointer deallocator = NULL ) 
   {
     this->m_Deallocator = deallocator;
-    m_DataType = TypeTraits::GetScalarDataType();
+    m_DataType = TypeTraits::DataTypeID;
     Data = static_cast<T*>( data );
     DataSize = datasize;
     PaddingFlag = paddingflag;
@@ -116,7 +119,7 @@ public:
    */
   TemplateArray ( const size_t datasize = 0 ) 
   {
-    m_DataType = TypeTraits::GetScalarDataType();
+    m_DataType = TypeTraits::DataTypeID;
     Data = NULL;
     this->Alloc( datasize ); 
   }
@@ -181,7 +184,7 @@ public:
   }
   
   /// Return id of primitive data type handled by this object.
-  virtual ScalarDataType GetType () const { return TypeTraits::GetScalarDataType(); }
+  virtual ScalarDataType GetType () const { return TypeTraits::DataTypeID; }
 
   /// Return size in bytes of the primitive data type handled by this object.
   virtual size_t GetItemSize () const { return sizeof(T); }
@@ -427,7 +430,7 @@ public:
 #pragma omp parallel for    
     for ( int i = 0; i < static_cast<int>( this->DataSize ); ++i )
       if ( ! PaddingFlag || (Data[i] != Padding ) )
-	Data[i] = TypeTraits::Abs( Data[i] );
+	Data[i] = std::abs( Data[i] );
   }
   
   /** Get an item from the array.
