@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3812 $
+//  $Revision: 4106 $
 //
-//  $LastChangedDate: 2012-02-02 15:52:58 -0800 (Thu, 02 Feb 2012) $
+//  $LastChangedDate: 2012-03-30 13:48:41 -0700 (Fri, 30 Mar 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -119,6 +119,9 @@ public:
    */
   virtual bool Get ( Types::DataItem&, const size_t ) const = 0;
 
+  /// Return data or a given default value if no data exists there.
+  virtual Types::DataItem ValueAt ( const size_t idx, const Types::DataItem defaultValue = 0.0 ) const = 0;
+  
   /** Get a sequence of items from the array.
    *\param values This must point to an allocated array of at least as many
    * Types::DataItem objects as given in the "length" parameter.
