@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4236 $
+//  $Revision: 4427 $
 //
-//  $LastChangedDate: 2012-04-20 14:55:02 -0700 (Fri, 20 Apr 2012) $
+//  $LastChangedDate: 2012-06-12 11:23:22 -0700 (Tue, 12 Jun 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -39,77 +39,79 @@ namespace
 cmtk
 {
 
+UniformVolume::UniformVolume 
+( const UniformVolume& other ) : Volume( other ), m_Delta( other.m_Delta ), m_IndexToPhysicalMatrix( other.m_IndexToPhysicalMatrix ) {}
+
 UniformVolume::UniformVolume
 ( const DataGrid::IndexType& dims, const Self::CoordinateVectorType& size, TypedArray::SmartPtr& data )
+  : Volume( dims, size, data )
 {
-  this->SetData( data );
-  this->SetDims( dims );
+  for ( int i=0; i<3; ++i ) 
+    {
+    this->m_Delta[i] = ( this->m_Dims[i] == 1 ) ? 0 : this->m_Size[i] / (this->m_Dims[i] - 1);
+    }
   
-  for ( int i=0; i<3; ++i ) {
-    Size[i] = static_cast<Types::Coordinate>( size[i] );
-    this->m_Delta[i] = ( this->m_Dims[i] == 1 ) ? 0 : Size[i] / (this->m_Dims[i] - 1);
-  }
-
   this->CropRegion() = this->GetWholeImageRegion();
   this->CreateDefaultIndexToPhysicalMatrix();
 }
 
 UniformVolume::UniformVolume
 ( const DataGrid::IndexType& dims, const Types::Coordinate deltaX, const Types::Coordinate deltaY, const Types::Coordinate deltaZ, TypedArray::SmartPtr& data )
+  : Volume( dims, dims, data )
 {
-  this->SetData( data );
-  this->SetDims( dims );
-
   this->m_Delta[0] = deltaX;
   this->m_Delta[1] = deltaY;
   this->m_Delta[2] = deltaZ;
 
   for ( int i=0; i<3; ++i )
-    Size[i] = this->m_Delta[i] * (this->m_Dims[i]-1);
+    this->m_Size[i] = this->m_Delta[i] * (this->m_Dims[i]-1);
 
   this->CropRegion() = this->GetWholeImageRegion();
   this->CreateDefaultIndexToPhysicalMatrix();
 }
 
-UniformVolume::UniformVolume 
-( const UniformVolume& other, const Types::Coordinate resolution, const bool allowUpsampling ) 
-  : Volume()
+UniformVolume* 
+UniformVolume::GetResampled
+( const Types::Coordinate resolution, const bool allowUpsampling ) const
 {
   Self::IndexType newDims;
+  Self::SpaceVectorType newSize;
+  Self::SpaceVectorType newDelta;
+
   for ( int dim=0; dim<3; ++dim ) 
     {
-    Size[dim] = other.Size[dim];
-    int new_dims=(int) (Size[dim]/resolution)+1;
-    if ( allowUpsampling || (new_dims<=other.m_Dims[dim]) ) 
+    newSize[dim] = this->m_Size[dim];
+    const int new_dims=(int) (newSize[dim]/resolution)+1;
+    if ( allowUpsampling || (new_dims<=this->m_Dims[dim]) ) 
       {
       newDims[dim]=new_dims;
-      this->m_Delta[dim]=Size[dim]/(new_dims-1);
+      newDelta[dim] = newSize[dim]/(new_dims-1);
       } 
     else
       {
-      if ( other.m_Dims[dim] == 1 ) 
+      if ( this->m_Dims[dim] == 1 ) 
 	{
-	this->m_Delta[dim] = Size[dim];
+	newDelta[dim] = newSize[dim];
 	newDims[dim] = 1;
 	} 
       else 
 	{
-	this->m_Delta[dim] = other.m_Delta[dim];
-	newDims[dim] = ((int)(Size[dim]/this->m_Delta[dim])) + 1;
-	Size[dim] = (newDims[dim]-1) * this->m_Delta[dim];
+	newDelta[dim] = this->m_Delta[dim];
+	newDims[dim] = ((int)(newSize[dim]/newDelta[dim])) + 1;
+	newSize[dim] = (newDims[dim]-1) * newDelta[dim];
 	}
       }
     }
-  
-  this->SetDims( newDims );
-  TypedArray::SmartPtr resampledData( this->Resample( other ) );
-  this->SetData( resampledData	 );
-  
-  this->m_IndexToPhysicalMatrix = other.m_IndexToPhysicalMatrix;
 
-  this->SetHighResCropRegion( other.GetHighResCropRegion() );
-  this->SetOffset( other.m_Offset );
-  this->CopyMetaInfo( other );
+  UniformVolume* newVolume = new UniformVolume( newDims, newSize );
+  newVolume->SetData( TypedArray::SmartPtr( newVolume->Resample( *this ) ) );
+  
+  newVolume->m_IndexToPhysicalMatrix = this->m_IndexToPhysicalMatrix;
+  newVolume->SetHighResCropRegion( this->GetHighResCropRegion() );
+  newVolume->SetOffset( this->m_Offset );
+  newVolume->CopyMetaInfo( *this );
+
+  return newVolume;
 }
 
 UniformVolume*
@@ -149,7 +151,7 @@ UniformVolume::CloneVirtual() const
 UniformVolume*
 UniformVolume::CloneGridVirtual() const
 {
-  UniformVolume* clone = new UniformVolume( this->m_Dims, Size );
+  UniformVolume* clone = new UniformVolume( this->m_Dims, this->m_Size );
   clone->SetOffset( this->m_Offset );
   clone->CopyMetaInfo( *this );
   clone->m_IndexToPhysicalMatrix = this->m_IndexToPhysicalMatrix;
@@ -188,7 +190,7 @@ UniformVolume::GetDownsampledAndAveraged( const int (&downsample)[3] ) const
   
   // apply shift to origin
   Self::CoordinateVectorType offset( this->m_Offset );
-  offset += Self::CoordinateVectorType( shift );
+  offset += Self::CoordinateVectorType::FromPointer( shift );
   dsVolume->SetOffset( offset );
   
   // set crop region while considering new image offset
@@ -255,14 +257,14 @@ UniformVolume::GetInterleavedSubVolume
   for ( int dim = 0; dim < 3; ++dim )
     {
     dims[dim] = this->m_Dims[dim];
-    size[dim] = this->Size[ dim ];
+    size[dim] = this->m_Size[ dim ];
     }
   dims[axis] = this->m_Dims[axis] / factor;
   if ( this->m_Dims[axis] % factor > idx )
     ++dims[axis];
   size[axis] = (dims[axis]-1) * factor * this->m_Delta[axis];
   
-  Self::CoordinateVectorType offset( Self::CoordinateVectorType::Init( 0 ) );
+  Self::CoordinateVectorType offset( 0.0 );
   offset[axis] = idx * this->m_Delta[axis];
   
   UniformVolume* volume = new UniformVolume( dims, size );
@@ -299,7 +301,7 @@ UniformVolume::GetInterleavedPaddedSubVolume
   if ( this->m_Dims[axis] % factor > idx )
     ++sDims;
 
-  UniformVolume* volume = new UniformVolume( this->m_Dims, this->Size );
+  UniformVolume* volume = new UniformVolume( this->m_Dims, this->m_Size );
   (volume->CreateDataArray( this->GetData()->GetType() ))->Fill( 0.0 );
   volume->SetOffset( this->m_Offset );
   for ( int i = 0; i < sDims; ++i )
@@ -345,9 +347,9 @@ UniformVolume::GetOrthoSlice
   ScalarImage* sliceImage = DataGrid::GetOrthoSlice( axis, plane );
   sliceImage->SetImageSlicePosition( this->GetPlaneCoord( axis, plane ) );
 
-  Self::CoordinateVectorType imageOffset( Self::CoordinateVectorType::Init( 0 ) );
-  Self::CoordinateVectorType directionX( Self::CoordinateVectorType::Init( 0 ) );
-  Self::CoordinateVectorType directionY( Self::CoordinateVectorType::Init( 0 ) );
+  Self::CoordinateVectorType imageOffset( 0.0 );
+  Self::CoordinateVectorType directionX( 0.0 );
+  Self::CoordinateVectorType directionY( 0.0 );
   switch ( axis ) 
     {
     case AXIS_X:
