@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
-//  Copyright 2004-2011 SRI International
+//  Copyright 2004-2012 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3646 $
+//  $Revision: 4375 $
 //
-//  $LastChangedDate: 2011-12-22 10:10:55 -0800 (Thu, 22 Dec 2011) $
+//  $LastChangedDate: 2012-05-30 13:01:18 -0700 (Wed, 30 May 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -36,6 +36,8 @@
 
 #include <System/cmtkThreadPool.h>
 
+#include <limits>
+
 namespace
 cmtk
 {
@@ -155,7 +157,7 @@ UniformVolume::ResampleThreadPoolExecuteLabels( void *const arg, const size_t ta
 	if ( maxLabelWeight > 0 )
 	  dest[offset] = maxLabelIndex;
 	else 
-	  dest[offset] = MathUtil::GetDoubleNaN();
+	  dest[offset] = std::numeric_limits<double>::signaling_NaN();
 	}
       }
     }
@@ -223,7 +225,7 @@ UniformVolume::ResampleThreadPoolExecuteGrey( void *const arg, const size_t task
 	  } 
 	else
 	  {
-	  dest[offset] = MathUtil::GetDoubleNaN();
+	  dest[offset] = std::numeric_limits<double>::signaling_NaN();
 	  }
 	}
       }
