@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
-//  Copyright 2004-2011 SRI International
+//  Copyright 2004-2012 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4236 $
+//  $Revision: 4381 $
 //
-//  $LastChangedDate: 2012-04-20 14:55:02 -0700 (Fri, 20 Apr 2012) $
+//  $LastChangedDate: 2012-05-30 14:18:15 -0700 (Wed, 30 May 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -55,7 +55,7 @@ UniformVolume::GetReoriented( const char* newOrientation ) const
   DataGrid::SmartPtr temp( DataGrid::GetReoriented( newOrientation ) );
 
   AnatomicalOrientation::PermutationMatrix pmatrix( this->m_Dims, curOrientation, newOrientation );
-  FixedVector<3,Types::Coordinate> newSize = pmatrix.GetPermutedArray( this->Size );
+  FixedVector<3,Types::Coordinate> newSize = pmatrix.GetPermutedArray( this->m_Size );
   
   UniformVolume::SmartPtr result( new UniformVolume( temp->GetDims(), newSize, temp->GetData() ) );
   result->m_Offset = pmatrix.GetPermutedArray( this->m_Offset );
