@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4093 $
+//  $Revision: 4427 $
 //
-//  $LastChangedDate: 2012-03-27 13:05:25 -0700 (Tue, 27 Mar 2012) $
+//  $LastChangedDate: 2012-06-12 11:23:22 -0700 (Tue, 12 Jun 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -262,7 +262,7 @@ public:
   /// Get shifted control point position by offset.
   virtual Self::SpaceVectorType GetShiftedControlPointPositionByOffset( const size_t offset ) const 
   { 
-    return Self::SpaceVectorType( this->m_Parameters + 3 * offset );
+    return Self::SpaceVectorType::FromPointer( this->m_Parameters + 3 * offset );
   }
 
   /// Set shifted control point position.
