@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3766 $
+//  $Revision: 4183 $
 //
-//  $LastChangedDate: 2012-01-31 13:52:22 -0800 (Tue, 31 Jan 2012) $
+//  $LastChangedDate: 2012-04-12 15:47:36 -0700 (Thu, 12 Apr 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -39,8 +39,9 @@
 #include <Base/cmtkAnatomicalOrientationBase.h>
 #include <Base/cmtkVector.h>
 #include <Base/cmtkFixedVector.h>
+#include <Base/cmtkRegion.h>
 #include <Base/cmtkBitVector.h>
-#include <Base/cmtkMatchedLandmarkList.h>
+#include <Base/cmtkLandmarkPairList.h>
 
 #include <System/cmtkSmartPtr.h>
 
@@ -67,8 +68,11 @@ public:
   /// Smart pointer-to-const for this class.
   typedef SmartConstPointer<Self> SmartConstPtr;
 
+  /// Region type.
+  typedef Region<3,Types::Coordinate> SpaceRegionType;
+
   /// Three-dimensional vector type.
-  typedef FixedVector<3,Types::Coordinate> SpaceVectorType;
+  typedef SpaceRegionType::IndexType SpaceVectorType;
 
   /// Pointer to warp parameter array.
   Types::Coordinate *m_Parameters;
@@ -193,7 +197,7 @@ public:
    * What is actually returned is the mean squared distance of source
    * landmark after transformation and desired target landmark.
    */
-  virtual Types::Coordinate GetLandmarksMSD( const MatchedLandmarkList* ll ) const;
+  virtual Types::Coordinate GetLandmarksMSD( const LandmarkPairList& ll ) const;
   
 protected:
   /** Encapsulated representation of the transformation parameters.
