@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3713 $
+//  $Revision: 4344 $
 //
-//  $LastChangedDate: 2012-01-10 15:33:21 -0800 (Tue, 10 Jan 2012) $
+//  $LastChangedDate: 2012-05-11 14:51:08 -0700 (Fri, 11 May 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -39,8 +39,8 @@ cmtk
 /** \addtogroup IO */
 //@{
 
-ClassStream& 
-operator << ( ClassStream& stream, const AffineXform& affineXform )
+ClassStreamOutput& 
+operator << ( ClassStreamOutput& stream, const AffineXform& affineXform )
 {
   stream.Begin( "affine_xform" );
   stream.WriteCoordinateArray( "xlate", affineXform.RetXlate(), 3 );
@@ -56,8 +56,8 @@ operator << ( ClassStream& stream, const AffineXform& affineXform )
   return stream;
 }
  
-ClassStream& 
-operator >> ( ClassStream& stream, AffineXform::SmartPtr& affineXform )
+ClassStreamInput& 
+operator >> ( ClassStreamInput& stream, AffineXform::SmartPtr& affineXform )
 {
   try
     {
@@ -71,8 +71,8 @@ operator >> ( ClassStream& stream, AffineXform::SmartPtr& affineXform )
   return stream;
 }
 
-ClassStream& 
-operator >> ( ClassStream& stream, AffineXform& affineXform )
+ClassStreamInput& 
+operator >> ( ClassStreamInput& stream, AffineXform& affineXform )
 {
   CoordinateVector pVector( 15 );
   Types::Coordinate* parameters = pVector.Elements;
