@@ -22,11 +22,11 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4260 $
+//  $Revision: 4400 $
 //
-//  $LastChangedDate: 2012-04-25 16:34:20 -0700 (Wed, 25 Apr 2012) $
+//  $LastChangedDate: 2012-05-31 11:53:17 -0700 (Thu, 31 May 2012) $
 //
-//  $LastChangedBy: torstenrohlfing $
+//  $LastChangedBy: torsten_at_home $
 //
 */
 
@@ -152,18 +152,6 @@ FileFormat::Identify( const std::string& path, const bool decompress )
   return FILEFORMAT_NEXIST;
 }
 
-FileFormatID 
-FileFormat::GetID( const std::string& name )
-{
-  for ( unsigned int idx = 0; FileFormatName[idx]; ++idx ) 
-    {
-    if ( name == std::string( FileFormatName[idx] ) )
-      return static_cast<FileFormatID>( idx );
-    }
-  
-  return FILEFORMAT_UNKNOWN;
-}
-
 std::string
 FileFormat::Describe( const FileFormatID id )
 {
