@@ -22,11 +22,11 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4260 $
+//  $Revision: 4400 $
 //
-//  $LastChangedDate: 2012-04-25 16:34:20 -0700 (Wed, 25 Apr 2012) $
+//  $LastChangedDate: 2012-05-31 11:53:17 -0700 (Thu, 31 May 2012) $
 //
-//  $LastChangedBy: torstenrohlfing $
+//  $LastChangedBy: torsten_at_home $
 //
 */
 
@@ -107,10 +107,6 @@ public:
    */
   static FileFormatID Identify( const std::string& path /*!< Image path. */, const bool decompress = true /*!< If set, compressed files are decompressed before determining their file type.*/ );
 
-  /** Return ID for given file format name.
-   */
-  static FileFormatID GetID( const std::string& name );
-
   /** Return textual description of identified file format.
    */
   static std::string Describe( const FileFormatID id );
