@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4260 $
+//  $Revision: 4423 $
 //
-//  $LastChangedDate: 2012-04-25 16:34:20 -0700 (Wed, 25 Apr 2012) $
+//  $LastChangedDate: 2012-06-11 16:13:37 -0700 (Mon, 11 Jun 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -34,7 +34,6 @@
 
 #include <IO/cmtkFileFormat.h>
 #include <IO/cmtkVolumeIO.h>
-#include <IO/cmtkClassStream.h>
 
 #include <string>
 #include <limits.h>
@@ -207,16 +206,9 @@ Study::ReadVolume( const bool reRead, const char* orientation )
       }
     }
   
-  if ( this->m_Volume ) 
+  if ( this->m_Volume && this->m_Volume->GetData() ) 
     {
-    if ( this->m_LandmarkList ) 
-      {
-      this->m_Volume->m_LandmarkList = this->m_LandmarkList;
-      }
-    if ( this->m_Volume->GetData() ) 
-      {
-      return true;
-      }
+    return true;
     }
   
   this->m_Volume = oldVolume;
