@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
-//  Copyright 2004-2011 SRI International
+//  Copyright 2004-2012 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3582 $
+//  $Revision: 4260 $
 //
-//  $LastChangedDate: 2011-11-29 11:21:34 -0800 (Tue, 29 Nov 2011) $
+//  $LastChangedDate: 2012-04-25 16:34:20 -0700 (Wed, 25 Apr 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -45,6 +45,8 @@
 
 #include <IO/cmtkFileFormat.h>
 
+#include <string>
+
 namespace
 cmtk
 {
@@ -81,7 +83,7 @@ class Study
   cmtkGetSetMacroString(Name);
 
   /// Textual description of study file type.
-  cmtkGetSetMacroString(Description);
+  cmtkGetSetMacro(std::string,Description);
 
   /// Textual description of study file type.
   cmtkGetSetMacroString(Modality);
