@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4260 $
+//  $Revision: 4427 $
 //
-//  $LastChangedDate: 2012-04-25 16:34:20 -0700 (Wed, 25 Apr 2012) $
+//  $LastChangedDate: 2012-06-12 11:23:22 -0700 (Tue, 12 Jun 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -75,9 +75,9 @@ VolumeFromFile::ReadNRRD( const std::string& pathHdr )
 
     const int dims[3] = 
       { 
-	(nrrd->dim > 0) ? nrrd->axis[0].size : 1,
-	(nrrd->dim > 1) ? nrrd->axis[1].size : 1,
-	(nrrd->dim > 2) ? nrrd->axis[2].size : 1 
+	static_cast<int>( (nrrd->dim > 0) ? nrrd->axis[0].size : 1 ),
+	static_cast<int>( (nrrd->dim > 1) ? nrrd->axis[1].size : 1 ),
+	static_cast<int>( (nrrd->dim > 2) ? nrrd->axis[2].size : 1 ) 
       };
 
     // for each axis, if spacing is NaN, use direction vector to compute spacing.
@@ -102,7 +102,7 @@ VolumeFromFile::ReadNRRD( const std::string& pathHdr )
 	}
       }
     const Types::Coordinate size[3] = { (dims[0]-1) * spacing[0], (dims[1]-1) * spacing[1], (dims[2]-1) * spacing[2] };
-    volume = UniformVolume::SmartPtr( new UniformVolume( DataGrid::IndexType( dims ),UniformVolume::CoordinateVectorType( size ) ) );
+    volume = UniformVolume::SmartPtr( new UniformVolume( DataGrid::IndexType::FromPointer( dims ),UniformVolume::CoordinateVectorType::FromPointer( size ) ) );
 
     ScalarDataType type = TYPE_NONE;
     switch ( nrrd->type )
