@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
-//  Copyright 2004-2011 SRI International
+//  Copyright 2004-2012 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3672 $
+//  $Revision: 3957 $
 //
-//  $LastChangedDate: 2011-12-23 12:56:49 -0800 (Fri, 23 Dec 2011) $
+//  $LastChangedDate: 2012-03-01 15:14:39 -0800 (Thu, 01 Mar 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -2187,7 +2187,7 @@ lbfgsbminimize
   int ileave;
   int nenter;
   ap::real_value_type theta;
-  ap::real_value_type fold;
+  ap::real_value_type fold = 0;
   ap::real_value_type dr;
   ap::real_value_type rr;
   ap::real_value_type dnrm;
