@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4142 $
+//  $Revision: 4427 $
 //
-//  $LastChangedDate: 2012-04-06 15:35:21 -0700 (Fri, 06 Apr 2012) $
+//  $LastChangedDate: 2012-06-12 11:23:22 -0700 (Tue, 12 Jun 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -35,7 +35,6 @@
 #include <Base/cmtkLandmark.h>
 #include <Base/cmtkLandmarkList.h>
 
-#include <IO/cmtkClassStream.h>
 #include <Qt/cmtkQtIcons.h>
 
 #include <qapplication.h>
@@ -495,11 +494,11 @@ QtTriplanarWindow::UpdateDialog()
       ScrollRenderViewCo->slotSetNumberOfSlices( VolumeDims[AXIS_Y] );
       
       LocationValidatorX->setBottom( 0 );
-      LocationValidatorX->setTop( volume->Size[AXIS_X] );
+      LocationValidatorX->setTop( volume->m_Size[AXIS_X] );
       LocationValidatorY->setBottom( 0 );
-      LocationValidatorY->setTop( volume->Size[AXIS_Y] );
+      LocationValidatorY->setTop( volume->m_Size[AXIS_Y] );
       LocationValidatorZ->setBottom( 0 );
-      LocationValidatorZ->setTop( volume->Size[AXIS_Z] );
+      LocationValidatorZ->setTop( volume->m_Size[AXIS_Z] );
       } 
     else
       {
@@ -667,7 +666,7 @@ QtTriplanarWindow::slotGoToLocation( const QString& xyz )
     }
   else
     {
-    this->slotMouse3D( Qt::LeftButton, UniformVolume::CoordinateVectorType( v ) );
+    this->slotMouse3D( Qt::LeftButton, UniformVolume::CoordinateVectorType::FromPointer( v ) );
     }
 }
 
@@ -834,7 +833,7 @@ QtTriplanarWindow::slotGoToLocation()
 
   // Pretend there was a button event at the given location
   const double location[3] = { LocationEntryX->text().toDouble(), LocationEntryY->text().toDouble(), LocationEntryZ->text().toDouble() };
-  this->slotMouse3D( Qt::LeftButton, UniformVolume::CoordinateVectorType( location ) );
+  this->slotMouse3D( Qt::LeftButton, UniformVolume::CoordinateVectorType::FromPointer( location ) );
 }
 
 void
@@ -962,7 +961,7 @@ QtTriplanarWindow::slotAddLandmark()
   if ( ok && !name.isEmpty() ) 
     {
     Types::Coordinate location[3] = { LocationEntryX->text().toDouble(), LocationEntryY->text().toDouble(), LocationEntryZ->text().toDouble() };
-    ll->push_back( Landmark( name.toStdString(), Landmark::SpaceVectorType( location ) ) );
+    ll->push_back( Landmark( name.toStdString(), Landmark::SpaceVectorType::FromPointer( location ) ) );
     LandmarkBox->addItem( name );
     LandmarkBox->setCurrentIndex( this->LandmarkBox->findText( name ) );
     
