@@ -20,9 +20,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3947 $
+//  $Revision: 4111 $
 //
-//  $LastChangedDate: 2012-02-29 12:40:17 -0800 (Wed, 29 Feb 2012) $
+//  $LastChangedDate: 2012-03-30 14:30:21 -0700 (Fri, 30 Mar 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -33,7 +33,7 @@
 #include <Base/cmtkDataGrid.h>
 #include <Base/cmtkSincInterpolator.h>
 #include <Base/cmtkRegionIndexIterator.h>
-#include <Base/cmtkUniformVolumeFilter.h>
+#include <Base/cmtkUniformVolumeGaussianFilter.h>
 
 #include <System/cmtkExitException.h>
 #include <System/cmtkDebugOutput.h>
@@ -46,7 +46,7 @@
 const int cmtk::EchoPlanarUnwarpFunctional::InterpolationKernelRadius = 2;
 
 cmtk::EchoPlanarUnwarpFunctional::EchoPlanarUnwarpFunctional
-( UniformVolume::SmartConstPtr& imageFwd, UniformVolume::SmartConstPtr& imageRev, const byte phaseEncodeDirection )
+( UniformVolume::SmartConstPtr& imageFwd, UniformVolume::SmartConstPtr& imageRev, const byte phaseEncodeDirection, const bool initShiftCentersOfMass )
   : m_ImageGrid( imageFwd->CloneGrid() ), 
     m_ImageFwd( imageFwd ), 
     m_ImageRev( imageRev ), 
@@ -62,8 +62,15 @@ cmtk::EchoPlanarUnwarpFunctional::EchoPlanarUnwarpFunctional
     }
   
   this->m_Deformation.setbounds( 1, this->m_ImageGrid->GetNumberOfPixels() );
-  for ( size_t i = 1; i < 1+this->m_ImageGrid->GetNumberOfPixels(); ++i )
-    this->m_Deformation(i) = 0.0;
+  if ( initShiftCentersOfMass )
+    {
+    this->InitShiftCentersOfMass();
+    }
+  else
+    {
+    for ( size_t i = 1; i < 1+this->m_ImageGrid->GetNumberOfPixels(); ++i )
+      this->m_Deformation(i) = 0.0;
+    }
 
   this->m_UnwarpImageFwd.resize( this->m_ImageGrid->GetNumberOfPixels() );
   this->m_UnwarpImageRev.resize( this->m_ImageGrid->GetNumberOfPixels() );
@@ -77,22 +84,60 @@ cmtk::EchoPlanarUnwarpFunctional::EchoPlanarUnwarpFunctional
   this->m_ReadoutDirection = dims.MaxIndex();
 }
 
+void
+cmtk::EchoPlanarUnwarpFunctional::InitShiftCentersOfMass()
+{
+  DebugOutput( 9 ) << "Initializing by shifting rows according to centers of mass.\n";
+
+  const DataGrid::RegionType wholeImageRegion = this->m_ImageGrid->GetWholeImageRegion();
+
+  DataGrid::RegionType faceRegion = wholeImageRegion;
+  faceRegion.To()[this->m_PhaseEncodeDirection] = faceRegion.From()[this->m_PhaseEncodeDirection]+1;
+
+  for ( RegionIndexIterator<DataGrid::RegionType> it( faceRegion ); it != it.end(); ++it )
+    {
+    // for each row, compute the two centers of mass
+    double totalMassFwd = 0, centerOfMassFwd = 0, totalMassRev = 0, centerOfMassRev = 0;
+
+    DataGrid::IndexType idx = it.Index();
+    for ( idx[this->m_PhaseEncodeDirection] = wholeImageRegion.From()[this->m_PhaseEncodeDirection]; idx[this->m_PhaseEncodeDirection] < wholeImageRegion.To()[this->m_PhaseEncodeDirection]; ++idx[this->m_PhaseEncodeDirection] )
+      {
+      const Types::DataItem valueFwd = this->m_ImageFwd->GetDataAt( this->m_ImageFwd->GetOffsetFromIndex( idx ) );
+      totalMassFwd += valueFwd;
+      centerOfMassFwd += idx[this->m_PhaseEncodeDirection] * valueFwd;
+
+      const Types::DataItem valueRev = this->m_ImageRev->GetDataAt( this->m_ImageRev->GetOffsetFromIndex( idx ) );
+      totalMassRev += valueRev;
+      centerOfMassRev += idx[this->m_PhaseEncodeDirection] * valueRev;
+      }
+
+    centerOfMassFwd /= totalMassFwd;
+    centerOfMassRev /= totalMassRev;
+
+    const double delta = (centerOfMassFwd - centerOfMassRev) / 2;
+    for ( idx[this->m_PhaseEncodeDirection] = wholeImageRegion.From()[this->m_PhaseEncodeDirection]; idx[this->m_PhaseEncodeDirection] < wholeImageRegion.To()[this->m_PhaseEncodeDirection]; ++idx[this->m_PhaseEncodeDirection] )
+      {
+      this->m_Deformation( 1 + this->m_ImageFwd->GetOffsetFromIndex( idx ) ) = delta;
+      }
+    }
+}
+
 void
 cmtk::EchoPlanarUnwarpFunctional::SetSmoothingKernelWidth( const Units::GaussianSigma& sigma, const Types::Coordinate maxError )
 {
   if ( sigma.Value() > 0 )
     {
     {
-    UniformVolumeFilter filterFwd( this->m_ImageFwd );
+    UniformVolumeGaussianFilter filterFwd( this->m_ImageFwd );
     UniformVolume::SmartPtr smooth = UniformVolume::SmartPtr( this->m_ImageGrid->CloneGrid() );
-    smooth->SetData( filterFwd.GetDataGaussFiltered1D( this->m_PhaseEncodeDirection, sigma, maxError ) );
+    smooth->SetData( filterFwd.GetFiltered1D( this->m_PhaseEncodeDirection, sigma, maxError ) );
     this->m_SmoothImageFwd = smooth;
     }
 
     {
-    UniformVolumeFilter filterRev( this->m_ImageRev );
+    UniformVolumeGaussianFilter filterRev( this->m_ImageRev );
     UniformVolume::SmartPtr smooth = UniformVolume::SmartPtr( this->m_ImageGrid->CloneGrid() );
-    smooth->SetData( filterRev.GetDataGaussFiltered1D( this->m_PhaseEncodeDirection, sigma, maxError ) );
+    smooth->SetData( filterRev.GetFiltered1D( this->m_PhaseEncodeDirection, sigma, maxError ) );
     this->m_SmoothImageRev = smooth;
     }    
     }
