@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
-//  Copyright 2004-2011 SRI International
+//  Copyright 2004-2012 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3647 $
+//  $Revision: 4423 $
 //
-//  $LastChangedDate: 2011-12-22 10:49:31 -0800 (Thu, 22 Dec 2011) $
+//  $LastChangedDate: 2012-06-11 16:13:37 -0700 (Mon, 11 Jun 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -41,7 +41,8 @@
 #include <System/cmtkMountPoints.h>
 
 #include <IO/cmtkXformIO.h>
-#include <IO/cmtkClassStream.h>
+#include <IO/cmtkClassStreamInput.h>
+#include <IO/cmtkClassStreamOutput.h>
 #include <IO/cmtkClassStreamAffineXform.h>
 #include <IO/cmtkVolumeIO.h>
 #include <IO/cmtkSplineWarpXformITKIO.h>
@@ -160,7 +161,6 @@ ElasticRegistrationCommandLine
     cl.AddOption( Key( "jacobian-weight" ), &this->m_JacobianConstraintWeight, "Weight for Jacobian-based local volume preservation constraint" );
     cl.AddOption( Key( "energy-weight" ), &this->m_GridEnergyWeight, "Weight for grid bending energy constraint" );
     cl.AddOption( Key( "rigidity-weight" ), &this->m_RigidityConstraintWeight, "Weight for local rigidity constraint" );
-    cl.AddOption( Key( "landmark-weight" ), &this->m_LandmarkErrorWeight, "Weight for landmark misregistration registration" );
     cl.AddOption( Key( "ic-weight" ), &this->m_InverseConsistencyWeight, "Weight for inverse consistency constraint" );
     cl.AddOption( Key( "relax" ), &this->m_RelaxWeight, "Weight relaxation factor for alternating under-constrained iterations" );
     cl.AddSwitch( Key( "relax-to-unfold" ), &this->m_RelaxToUnfold, true, "Before each resolution level, regularize negative-Jacobian areas of the deformation to unfold them." );
@@ -248,7 +248,7 @@ ElasticRegistrationCommandLine
     
     DebugOutput( 1 ) << "Reading input studylist " << InputStudylist << "\n";
   
-    ClassStream classStream( MountPoints::Translate(InputStudylist),"registration", ClassStream::MODE_READ );
+    ClassStreamInput classStream( MountPoints::Translate(InputStudylist),"registration" );
     if ( ! classStream.IsValid() ) 
       {
       StdErr << "ERROR: Could not open studylist archive " << InputStudylist << ".\n";
@@ -458,7 +458,7 @@ ElasticRegistrationCommandLine::DoneResolution
 void
 ElasticRegistrationCommandLine::OutputWarp ( const char* path ) const
 {
-  ClassStream classStream( path, "studylist", ClassStream::MODE_WRITE );
+  ClassStreamOutput classStream( path, "studylist", ClassStreamOutput::MODE_WRITE );
   if ( ! classStream.IsValid() ) return;
 
   classStream.Begin( "studylist" );
@@ -475,7 +475,7 @@ ElasticRegistrationCommandLine::OutputWarp ( const char* path ) const
 
   classStream.Close();
 
-  classStream.Open( path, "settings", ClassStream::MODE_WRITE );
+  classStream.Open( path, "settings", ClassStreamOutput::MODE_WRITE );
   classStream.WriteInt( "algorithm", this->m_Algorithm );
   classStream.WriteBool( "use_maxnorm", UseMaxNorm );
   classStream.WriteDouble( "exploration", this->m_Exploration );
@@ -497,7 +497,6 @@ ElasticRegistrationCommandLine::OutputWarp ( const char* path ) const
   classStream.WriteDouble( "energy_constraint_weight", this->m_GridEnergyWeight );
   classStream.WriteDouble( "inverse_consistency_weight", this->m_InverseConsistencyWeight );
   classStream.WriteDouble( "weight_relaxation", this->m_RelaxWeight );
-  classStream.WriteDouble( "landmark_error_weight", this->m_LandmarkErrorWeight );
   classStream.WriteBool( "force_switch", this->ForceSwitchVolumes );
   classStream.WriteInt( "refine_grid", this->m_RefineGrid );
   classStream.WriteBool( "delay_refine_grid", this->m_DelayRefineGrid );
@@ -509,7 +508,7 @@ ElasticRegistrationCommandLine::OutputWarp ( const char* path ) const
 
   classStream.Close();
       
-  classStream.Open( path, "statistics", ClassStream::MODE_WRITE );
+  classStream.Open( path, "statistics", ClassStreamOutput::MODE_WRITE );
   classStream.WriteDouble( "time_level", this->GetLevelElapsedTime() );
   classStream.WriteDouble( "time_total", this->GetTotalElapsedTime() );
   classStream.WriteDouble( "walltime_level", this->GetLevelElapsedWalltime() );
@@ -532,7 +531,7 @@ ElasticRegistrationCommandLine::OutputWarp ( const char* path ) const
   const WarpXform::SmartPtr warp = WarpXform::SmartPtr::DynamicCastFrom( this->m_Xform );
   if ( warp ) 
     {
-    classStream.Open( path, "registration", ClassStream::MODE_WRITE );
+    classStream.Open( path, "registration", ClassStreamOutput::MODE_WRITE_ZLIB );
     if ( classStream.IsValid() ) 
       {
       classStream.Begin( "registration" );
