@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
-//  Copyright 2004-2011 SRI International
+//  Copyright 2004-2012 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4111 $
+//  $Revision: 4427 $
 //
-//  $LastChangedDate: 2012-03-30 14:30:21 -0700 (Fri, 30 Mar 2012) $
+//  $LastChangedDate: 2012-06-12 11:23:22 -0700 (Tue, 12 Jun 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -101,7 +101,7 @@ GroupwiseRegistrationFunctionalBase::CreateTemplateGridFromTargets
     {
     for ( int dim = 0; dim < 3; ++dim )
       {
-      templateSize[dim] = std::max( templateSize[dim], targets[i]->Size[dim] );
+      templateSize[dim] = std::max( templateSize[dim], targets[i]->m_Size[dim] );
       }
     templateDelta = std::min( templateDelta, targets[i]->GetMinDelta() );
     }
@@ -112,7 +112,7 @@ GroupwiseRegistrationFunctionalBase::CreateTemplateGridFromTargets
     templateSize[dim] = (templateDims[dim]-1) * templateDelta;
     }
   
-  UniformVolume::SmartPtr templateGrid( new UniformVolume( templateDims, FixedVector<3,Types::Coordinate>( templateSize ) ) );
+  UniformVolume::SmartPtr templateGrid( new UniformVolume( templateDims, FixedVector<3,Types::Coordinate>::FromPointer( templateSize ) ) );
   this->SetTemplateGrid( templateGrid, downsample );
 }
 
