@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3608 $
+//  $Revision: 3975 $
 //
-//  $LastChangedDate: 2011-12-02 10:47:18 -0800 (Fri, 02 Dec 2011) $
+//  $LastChangedDate: 2012-03-06 15:04:42 -0800 (Tue, 06 Mar 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -48,7 +48,7 @@ template<class TXform>
 GroupwiseRegistrationFunctionalXformTemplateBase<TXform>::GroupwiseRegistrationFunctionalXformTemplateBase() :
   m_HistogramBins( 64 ),
   m_HistogramKernelRadiusMax( 0 ),
-  m_MaxRelativeNumberOutsidePixels( 0.99 ), // if there is an image with more then 99% pixels outside FOV, registration probably failed
+  m_MaxRelativeNumberOutsidePixels( 0.99f ), // if there is an image with more then 99% pixels outside FOV, registration probably failed
   m_CropImageHistograms( false )
 {}
 
