@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3647 $
+//  $Revision: 4344 $
 //
-//  $LastChangedDate: 2011-12-22 10:49:31 -0800 (Thu, 22 Dec 2011) $
+//  $LastChangedDate: 2012-05-11 14:51:08 -0700 (Fri, 11 May 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -35,7 +35,7 @@
 #include <System/cmtkDebugOutput.h>
 
 #include <IO/cmtkGroupwiseRegistrationFunctionalIO.h>
-#include <IO/cmtkClassStream.h>
+#include <IO/cmtkClassStreamOutput.h>
 #include <IO/cmtkStudyList.h>
 #include <IO/cmtkClassStreamStudyList.h>
 #include <IO/cmtkVolumeIO.h>
@@ -56,16 +56,16 @@ GroupwiseRegistrationOutput::WriteGroupwiseArchive( const char* path ) const
   // create class stream archive.
   if ( path )
     {
-    ClassStream stream;
+    ClassStreamOutput stream;
     
     if ( this->m_OutputRootDirectory )
       {
       char completePath[PATH_MAX];
       snprintf( completePath, sizeof( completePath ), "%s%c%s", this->m_OutputRootDirectory, (int)CMTK_PATH_SEPARATOR, path );
-      stream.Open( completePath, ClassStream::MODE_WRITE );
+      stream.Open( completePath, ClassStreamOutput::MODE_WRITE_ZLIB );
       }
     else
-      stream.Open( path, ClassStream::MODE_WRITE );
+      stream.Open( path, ClassStreamOutput::MODE_WRITE_ZLIB );
     
     if ( ! stream.IsValid() ) return false;
     stream << *this->m_Functional;
