@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3722 $
+//  $Revision: 4426 $
 //
-//  $LastChangedDate: 2012-01-11 13:38:56 -0800 (Wed, 11 Jan 2012) $
+//  $LastChangedDate: 2012-06-12 10:30:56 -0700 (Tue, 12 Jun 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -156,8 +156,8 @@ ImagePairAffineRegistration
   UniformVolume::SmartPtr nextRef, nextFlt;
   if ( levelParameters->m_Resolution > 0 )
     {
-    nextRef = UniformVolume::SmartPtr( new UniformVolume( *this->m_ReferenceVolume, levelParameters->m_Resolution ) );
-    nextFlt = UniformVolume::SmartPtr( new UniformVolume( *this->m_FloatingVolume, levelParameters->m_Resolution ) );
+    nextRef = UniformVolume::SmartPtr( this->m_ReferenceVolume->GetResampled( levelParameters->m_Resolution ) );
+    nextFlt = UniformVolume::SmartPtr( this->m_FloatingVolume->GetResampled( levelParameters->m_Resolution ) );
     }
   else
     {
