@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
-//  Copyright 2004-2011 SRI International
+//  Copyright 2004-2012 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3647 $
+//  $Revision: 4423 $
 //
-//  $LastChangedDate: 2011-12-22 10:49:31 -0800 (Thu, 22 Dec 2011) $
+//  $LastChangedDate: 2012-06-11 16:13:37 -0700 (Mon, 11 Jun 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -41,7 +41,8 @@
 #include <System/cmtkMountPoints.h>
 
 #include <IO/cmtkXformIO.h>
-#include <IO/cmtkClassStream.h>
+#include <IO/cmtkClassStreamInput.h>
+#include <IO/cmtkClassStreamOutput.h>
 #include <IO/cmtkClassStreamAffineXform.h>
 #include <IO/cmtkVolumeIO.h>
 #include <IO/cmtkSplineWarpXformITKIO.h>
@@ -146,7 +147,6 @@ ImagePairNonrigidRegistrationCommandLine
     cl.BeginGroup( "Regularization", "Regularization parameters" );
     cl.AddOption( Key( "jacobian-constraint-weight" ), &this->m_JacobianConstraintWeight, "Weight for Jacobian-based local volume preservation constraint" );
     cl.AddOption( Key( "smoothness-constraint-weight" ), &this->m_GridEnergyWeight, "Weight for smoothness constraint based on second-order grid bending energy." );
-    cl.AddOption( Key( "landmark-constraint-weight" ), &this->m_LandmarkErrorWeight, "Weight for landmark misregistration registration" );
     cl.AddOption( Key( "inverse-consistency-weight" ), &this->m_InverseConsistencyWeight, "Weight for inverse consistency constraint" );
     cl.AddOption( Key( "constraint-relaxation-factor" ), &this->m_RelaxWeight, "Weight relaxation factor for alternating under-constrained iterations" );
     cl.AddSwitch( Key( "relax-to-unfold" ), &this->m_RelaxToUnfold, true, "Before each resolution level, regularize negative-Jacobian areas of the deformation to unfold them." );
@@ -245,7 +245,7 @@ ImagePairNonrigidRegistrationCommandLine
     
     DebugOutput( 1 ) << "Reading input studylist" << InputStudylist << "\n";
     
-    ClassStream classStream( MountPoints::Translate(InputStudylist),"registration", ClassStream::MODE_READ );
+    ClassStreamInput classStream( MountPoints::Translate(InputStudylist),"registration" );
     if ( ! classStream.IsValid() ) 
       {
       StdErr << "ERROR: Could not open studylist archive " << InputStudylist << ".\n";
@@ -438,7 +438,7 @@ ImagePairNonrigidRegistrationCommandLine::DoneResolution
 void
 ImagePairNonrigidRegistrationCommandLine::OutputWarp ( const char* path ) const
 {
-  ClassStream classStream( path, "studylist", ClassStream::MODE_WRITE );
+  ClassStreamOutput classStream( path, "studylist", ClassStreamOutput::MODE_WRITE );
   if ( ! classStream.IsValid() ) return;
 
   classStream.Begin( "studylist" );
@@ -455,7 +455,7 @@ ImagePairNonrigidRegistrationCommandLine::OutputWarp ( const char* path ) const
 
   classStream.Close();
 
-  classStream.Open( path, "settings", ClassStream::MODE_WRITE );
+  classStream.Open( path, "settings", ClassStreamOutput::MODE_WRITE );
   classStream.WriteInt( "algorithm", this->m_Algorithm );
   classStream.WriteBool( "use_maxnorm", this->m_UseMaxNorm );
   classStream.WriteDouble( "exploration", this->m_MaxStepSize );
@@ -472,7 +472,6 @@ ImagePairNonrigidRegistrationCommandLine::OutputWarp ( const char* path ) const
   classStream.WriteDouble( "energy_constraint_weight", this->m_GridEnergyWeight );
   classStream.WriteDouble( "inverse_consistency_weight", this->m_InverseConsistencyWeight );
   classStream.WriteDouble( "weight_relaxation", this->m_RelaxWeight );
-  classStream.WriteDouble( "landmark_error_weight", this->m_LandmarkErrorWeight );
   classStream.WriteInt( "refine_grid", this->m_RefineGrid );
   classStream.WriteBool( "delay_refine_grid", this->m_DelayRefineGrid );
   classStream.WriteBool( "adaptive_fix_parameters", this->m_AdaptiveFixParameters );
@@ -483,7 +482,7 @@ ImagePairNonrigidRegistrationCommandLine::OutputWarp ( const char* path ) const
 
   classStream.Close();
       
-  classStream.Open( path, "statistics", ClassStream::MODE_WRITE );
+  classStream.Open( path, "statistics", ClassStreamOutput::MODE_WRITE );
   classStream.WriteDouble( "time_level", this->GetLevelElapsedTime() );
   classStream.WriteDouble( "time_total", this->GetTotalElapsedTime() );
   classStream.WriteDouble( "walltime_level", this->GetLevelElapsedWalltime() );
@@ -506,7 +505,7 @@ ImagePairNonrigidRegistrationCommandLine::OutputWarp ( const char* path ) const
   const WarpXform::SmartPtr warp = WarpXform::SmartPtr::DynamicCastFrom( this->m_Xform );
   if ( warp ) 
     {
-    classStream.Open( path, "registration", ClassStream::MODE_WRITE );
+    classStream.Open( path, "registration", ClassStreamOutput::MODE_WRITE_ZLIB );
     if ( classStream.IsValid() ) 
       {
       classStream.Begin( "registration" );
