@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
-//  Copyright 2004-2011 SRI International
+//  Copyright 2004-2012 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3647 $
+//  $Revision: 4426 $
 //
-//  $LastChangedDate: 2011-12-22 10:49:31 -0800 (Thu, 22 Dec 2011) $
+//  $LastChangedDate: 2012-06-12 10:30:56 -0700 (Tue, 12 Jun 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -32,7 +32,8 @@
 
 #include "cmtkImageSymmetryPlaneCommandLineBase.h"
 
-#include <IO/cmtkClassStream.h>
+#include <IO/cmtkClassStreamInput.h>
+#include <IO/cmtkClassStreamOutput.h>
 #include <IO/cmtkVolumeIO.h>
 #include <IO/cmtkXformIO.h>
 
@@ -191,7 +192,7 @@ cmtk::ImageSymmetryPlaneCommandLineBase
 	{
 	Types::Coordinate voxelSize = this->m_Sampling * pow( 2.0, (this->m_Levels-level-2) );
 	DebugOutput( 1 ).GetStream().printf( "Entering level %d out of %d (%.2f mm voxel size)\n", level+1, this->m_Levels, voxelSize );
-	volume = UniformVolume::SmartPtr( new UniformVolume( *originalVolume, voxelSize ) );
+	volume = UniformVolume::SmartPtr( originalVolume->GetResampled( voxelSize ) );
 	} 
       else
 	{
@@ -233,7 +234,7 @@ cmtk::ImageSymmetryPlaneCommandLineBase
   
   if ( this->m_SymmetryOutFileName )
     {
-    ClassStream stream( this->m_SymmetryOutFileName, ClassStream::MODE_WRITE );
+    ClassStreamOutput stream( this->m_SymmetryOutFileName, ClassStreamOutput::MODE_WRITE );
     stream << this->m_SymmetryPlane;
     stream.Close();
     }
@@ -280,7 +281,7 @@ cmtk::ImageSymmetryPlaneCommandLineBase
     
     if ( this->m_SymmetryParametersFile ) 
       {
-      ClassStream inStream( this->m_SymmetryParametersFile, ClassStream::MODE_READ );
+      ClassStreamInput inStream( this->m_SymmetryParametersFile );
       if ( inStream.IsValid() ) 
 	{
 	ParametricPlane *plane = NULL;
