@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3819 $
+//  $Revision: 4381 $
 //
-//  $LastChangedDate: 2012-02-07 12:26:54 -0800 (Tue, 07 Feb 2012) $
+//  $LastChangedDate: 2012-05-30 14:18:15 -0700 (Wed, 30 May 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -99,7 +99,7 @@ SplineWarpCongealingFunctional
     const size_t numberOfControlPoints = this->m_VolumeOfInfluenceArray.size();
     
     const Vector3D templateFrom( this->m_TemplateGrid->m_Offset );
-    const Vector3D templateTo( this->m_TemplateGrid->m_Offset + this->m_TemplateGrid->Size );
+    const Vector3D templateTo( this->m_TemplateGrid->m_Offset + this->m_TemplateGrid->m_Size );
     Vector3D fromVOI, toVOI;
     
     std::vector<DataGrid::RegionType>::const_iterator voi = this->m_VolumeOfInfluenceArray.begin();
