@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4263 $
+//  $Revision: 4427 $
 //
-//  $LastChangedDate: 2012-04-25 17:10:54 -0700 (Wed, 25 Apr 2012) $
+//  $LastChangedDate: 2012-06-12 11:23:22 -0700 (Tue, 12 Jun 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -63,7 +63,7 @@ VoxelMatchingElasticFunctional::VoxelMatchingElasticFunctional
 {
   Dim = 0;
 
-  this->m_ReferenceDomain = UniformVolume::CoordinateRegionType( UniformVolume::CoordinateVectorType( UniformVolume::CoordinateVectorType::Init( 0 ) ), reference->Size );
+  this->m_ReferenceDomain = UniformVolume::CoordinateRegionType( UniformVolume::CoordinateVectorType( 0.0 ), reference->m_Size );
 
   this->m_AdaptiveFixParameters = false;
   this->m_AdaptiveFixThreshFactor = 0.5;
@@ -147,7 +147,7 @@ VoxelMatchingElasticFunctional_WarpTemplate<W>::SetWarpXform
   Warp = W::SmartPtr::DynamicCastFrom( warp );
   if ( Warp )
     {
-    Warp->RegisterVolume( ReferenceGrid );
+    Warp->RegisterVolume( *(ReferenceGrid) );
     
     if ( Dim != Warp->VariableParamVectorDim() ) 
       {
