@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4093 $
+//  $Revision: 4381 $
 //
-//  $LastChangedDate: 2012-03-27 13:05:25 -0700 (Tue, 27 Mar 2012) $
+//  $LastChangedDate: 2012-05-30 14:18:15 -0700 (Wed, 30 May 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -430,7 +430,7 @@ public:
 	if ( thread ) 
 	  {
 	  ThreadWarp[thread] = SplineWarpXform::SmartPtr( this->Warp->Clone() );
-	  ThreadWarp[thread]->RegisterVolume( this->ReferenceGrid );
+	  ThreadWarp[thread]->RegisterVolume( *(this->ReferenceGrid) );
 	  } 
 	else 
 	  {
