@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3812 $
+//  $Revision: 4344 $
 //
-//  $LastChangedDate: 2012-02-02 15:52:58 -0800 (Thu, 02 Feb 2012) $
+//  $LastChangedDate: 2012-05-11 14:51:08 -0700 (Fri, 11 May 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -50,7 +50,8 @@
 
 #include <System/cmtkTimers.h>
 #include <System/cmtkCommandLine.h>
-#include <IO/cmtkClassStream.h>
+
+#include <IO/cmtkClassStreamOutput.h>
 
 #include <stack>
 #include <string.h>
@@ -188,7 +189,7 @@ protected:
     UniformVolume::SmartPtr GetProcessedImage( const UniformVolume* original );
     
     /// Write settings of this object to class stream for archiving.
-    void WriteSettings( ClassStream& stream ) const;
+    void WriteSettings( ClassStreamOutput& stream ) const;
 
   private:
     /// Store the name that identifies this instance ("Reference" or "Floating")
