@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
-//  Copyright 2004-2011 SRI International
+//  Copyright 2004-2012 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,11 +22,11 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3483 $
+//  $Revision: 4303 $
 //
-//  $LastChangedDate: 2011-10-20 11:08:35 -0700 (Thu, 20 Oct 2011) $
+//  $LastChangedDate: 2012-05-03 14:58:17 -0700 (Thu, 03 May 2012) $
 //
-//  $LastChangedBy: torstenrohlfing $
+//  $LastChangedBy: torsten_at_home $
 //
 */
 
@@ -891,7 +891,7 @@ public:
     typedef SmartPointer<EnumGroupBase> SmartPtr;
 
     /// Constructor.
-    EnumGroupBase() : m_Properties( 0 ) {};
+    EnumGroupBase() : m_Properties( PROPS_XML ) {};
 
     /// Get key for the default value.
     std::string GetDefaultKey() const
@@ -1135,7 +1135,7 @@ public:
     typedef SmartPointer<KeyActionGroupType> SmartPtr;
     
     /// Constructor: set name and description.
-    KeyActionGroupType( const std::string& name, const std::string& description ) : m_Name( name ), m_Description( description ) {};
+    KeyActionGroupType( const std::string& name, const std::string& description ) : m_Name( name ), m_Description( description ), m_Properties( PROPS_XML ) {};
 
     /// Virtual destructor.
     virtual ~KeyActionGroupType() {}
