@@ -22,23 +22,17 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4039 $
+//  $Revision: 4399 $
 //
-//  $LastChangedDate: 2012-03-16 13:36:14 -0700 (Fri, 16 Mar 2012) $
+//  $LastChangedDate: 2012-05-31 11:51:50 -0700 (Thu, 31 May 2012) $
 //
-//  $LastChangedBy: torstenrohlfing $
+//  $LastChangedBy: torsten_at_home $
 //
 */
 
 #include "cmtkStrUtility.h"
 
 #include <string.h>
-#include <stdlib.h>
-#include <limits.h>
-
-#ifdef _MSC_VER
-#  include <direct.h>
-#endif
 
 namespace
 cmtk
@@ -84,65 +78,13 @@ StrNStr( const char* haystack, const size_t nBytes, const char* needle )
   return NULL;
 }
 
-void
-StrReplace( char*& s1, const char* s2 )
-{
-  StrFree( s1 );
-  if ( s2 )
-    s1 = strdup( s2 );
-  else
-    s1 = NULL;
-}
-
-void StrFree( char *const s )
-{
-  free( s );
-}
-
 int StrPrefixCmp( const char *s, const char* prefix )
 {
   return (0 == strncmp( s, prefix, strlen( prefix ) ));
 }
 
-static char StrBuffer[PATH_MAX];
-
-const char*
-StrDir( const char *path )
-{
-  const char *slash = strrchr( path, CMTK_PATH_SEPARATOR );
-  if ( slash && (slash != path) ) 
-    {
-    int dirLen = (slash-path);
-    strncpy( StrBuffer, path, dirLen );
-    StrBuffer[dirLen] = 0;
-    } 
-  else
-    {
-    if ( slash )
-      strcpy( StrBuffer, CMTK_PATH_SEPARATOR_STR );
-    else
-      strcpy( StrBuffer, path );
-    }
-  return StrBuffer;
-}
-
-const char*
-StrFName( const char *path )
-{
-  const char *slash = strrchr( path, CMTK_PATH_SEPARATOR );
-  if ( slash )
-    {
-    strcpy( StrBuffer, slash+1 );
-    } 
-  else
-    {
-    StrBuffer[0] = 0;
-    }
-  return StrBuffer;
-}
-
 std::string
-StrReplace
+StrReplaceByRules
 ( const std::string& str, const std::map<std::string,std::string>& rules, const bool multiple )
 {
   std::string result = str;
@@ -170,4 +112,33 @@ StrReplace
   return result;
 }
 
+std::string
+StrReplace( const std::string& str, const std::string& search, const std::string& replace )
+{
+  std::string result = str;
+
+  if ( ! search.empty() )
+    {
+    for ( size_t b = result.find(search, 0); b != result.npos; b = result.find(search, b) )
+      {
+      result.replace( b, search.size(), replace );
+      b += (replace.size() - search.size());
+      }
+    }
+
+  return result;
+}
+
+std::string
+StrMakeLegalInPath( const std::string& s )
+{
+  std::string result = s;
+  
+  result = StrReplace( result, " ", "_" );      
+  result = StrReplace( result, ":", "_" );  
+  
+  return result;
+}
+
+
 } // namespace cmtk
